"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class QSystemSemaphore(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qsystemsemaphore.html

    **Detailed Description**

    A semaphore is a generalization of a mutex. While a mutex can be locked only
    once, a semaphore can be acquired multiple times. Typically, a semaphore is
    used to protect a certain number of identical resources.

    Like its lighter counterpart **QSemaphore** , a QSystemSemaphore can be
    accessed from multiple **threads** . Unlike **QSemaphore** , a
    QSystemSemaphore can also be accessed from multiple **processes** . This
    means QSystemSemaphore is a much heavier class, so if your application
    doesn't need to access your semaphores across multiple processes, you will
    probably want to use **QSemaphore** .

    Semaphores support two fundamental operations, **acquire** () and
    **release** ():

    **acquire** () tries to acquire one resource. If there isn't a resource
    available, the call blocks until a resource becomes available. Then the
    resource is acquired and the call returns.

    **release** () releases one resource so it can be acquired by another
    process. The function can also be called with a parameter n > 1, which
    releases n resources.

    A system semaphore is created with a string key that other processes can use
    to use the same semaphore.

    Example: Create a system semaphore

    **QSystemSemaphore**  sem("market", 3, **QSystemSemaphore** ::Create);
    // resources available == 3
        sem.acquire();               // resources
    available == 2
        sem.acquire();               // resources available == 1
    sem.acquire();               // resources available == 0
        sem.release();
    // resources available == 1
        sem.release(2);              // resources
    available == 3

    A typical application of system semaphores is for controlling access to a
    circular buffer shared by a producer process and a consumer processes.

    **Platform-Specific Behavior**

    When using this class, be aware of the following platform differences:

    **Windows:** QSystemSemaphore does not own its underlying system semaphore.
    Windows owns it. This means that when all instances of QSystemSemaphore for
    a particular key have been destroyed, either by having their destructors
    called, or because one or more processes crash, Windows removes the
    underlying system semaphore.

    **Unix:**

    * QSystemSemaphore owns the underlying system semaphore in Unix systems.
    This means that the last process having an instance of QSystemSemaphore for
    a particular key must remove the underlying system semaphore in its
    destructor. If the last process crashes without running the QSystemSemaphore
    destructor, Unix does not automatically remove the underlying system
    semaphore, and the semaphore survives the crash. A subsequent process that
    constructs a QSystemSemaphore with the same key will then be given the
    existing system semaphore. In that case, if the QSystemSemaphore constructor
    has specified its **access mode**  as **Open** , its initial resource count
    will not be reset to the one provided but remain set to the value it
    received in the crashed process. To protect against this, the first process
    to create a semaphore for a particular key (usually a server), must pass its
    **access mode**  as **Create** , which will force Unix to reset the resource
    count in the underlying system semaphore.
      * When a process using
    QSystemSemaphore terminates for any reason, Unix automatically reverses the
    effect of all acquire operations that were not released. Thus if the process
    acquires a resource and then exits without releasing it, Unix will release
    that resource.

    **Apple platforms:** Sandboxed applications (including apps shipped through
    the Apple App Store) require the key to be in the form `<application group
    identifier>/<custom identifier>`, as documented **here**  and **here** , and
    the key length is limited to 30 characters.

    **See also** **QSharedMemory**  and **QSemaphore** .
    """

    class SystemSemaphoreError(enum.Enum):
        NoError: QSystemSemaphore = ...
        PermissionDenied: QSystemSemaphore = ...
        KeyError: QSystemSemaphore = ...
        AlreadyExists: QSystemSemaphore = ...
        NotFound: QSystemSemaphore = ...
        OutOfResources: QSystemSemaphore = ...
        UnknownError: QSystemSemaphore = ...

    class AccessMode(enum.Enum):
        Open: QSystemSemaphore = ...
        Create: QSystemSemaphore = ...

    def __init__(
        self,
        key: str,
        initialValue: int = ...,
        mode: "QSystemSemaphore.AccessMode" = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsystemsemaphore.html#QSystemSemaphore

        **QSystemSemaphore::QSystemSemaphore(const QString & key , int
        initialValue = 0, QSystemSemaphore::AccessMode mode = Open)**

        Requests a system semaphore for the specified **key**. The parameters
        **initialValue** and **mode** are used according to the following rules,
        which are system dependent.

        In Unix, if the **mode** is **Open**  and the system already has a
        semaphore identified by **key** , that semaphore is used, and the
        semaphore's resource count is not changed, i.e., **initialValue** is
        ignored. But if the system does not already have a semaphore identified
        by **key** , it creates a new semaphore for that key and sets its
        resource count to **initialValue**.

        In Unix, if the **mode** is **Create**  and the system already has a
        semaphore identified by **key** , that semaphore is used, and its
        resource count is set to **initialValue**. If the system does not
        already have a semaphore identified by **key** , it creates a new
        semaphore for that key and sets its resource count to **initialValue**.

        In Windows, **mode** is ignored, and the system always tries to create a
        semaphore for the specified **key**. If the system does not already have
        a semaphore identified as **key** , it creates the semaphore and sets
        its resource count to **initialValue**. But if the system already has a
        semaphore identified as **key** it uses that semaphore and ignores
        **initialValue**.

        The **mode**  parameter is only used in Unix systems to handle the case
        where a semaphore survives a process crash. In that case, the next
        process to allocate a semaphore with the same **key** will get the
        semaphore that survived the crash, and unless **mode** is **Create** ,
        the resource count will not be reset to **initialValue** but will retain
        the initial value it had been given by the crashed process.

        **See also** **acquire** () and **key** ().
        """
        ...

    def errorString(self) -> str:
        """
        https://doc.qt.io/qt-6/qsystemsemaphore.html#errorString

        **QString QSystemSemaphore::errorString() const**

        Returns a text description of the last error that occurred. If **error**
        () returns an **error value** , call this function to get a text string
        that describes the error.

        **See also** **error** ().
        """
        ...

    def error(self) -> "QSystemSemaphore.SystemSemaphoreError":
        """
        https://doc.qt.io/qt-6/qsystemsemaphore.html#error

        **QSystemSemaphore::SystemSemaphoreError QSystemSemaphore::error()
        const**

        Returns a value indicating whether an error occurred, and, if so, which
        error it was.

        **See also** **errorString** ().
        """
        ...

    def release(self, n: int = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qsystemsemaphore.html#release

        **bool QSystemSemaphore::release(int n = 1)**

        Releases **n** resources guarded by the semaphore. Returns `true` unless
        there is a system error.

        Example: Create a system semaphore having five resources; acquire them
        all and then release them all.

        **QSystemSemaphore**  sem("market", 5, **QSystemSemaphore** ::Create);
        for (int i = 0; i < 5; ++i)  // acquire all 5 resources
        sem.acquire();
            sem.release(5);              // release the 5
        resources

        This function can also "create" resources. For example, immediately
        following the sequence of statements above, suppose we add the
        statement:

        sem.release(10);          // "create" 10 new resources

        Ten new resources are now guarded by the semaphore, in addition to the
        five that already existed. You would not normally use this function to
        create more resources.

        **See also** **acquire** ().
        """
        ...

    def acquire(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsystemsemaphore.html#acquire

        **bool QSystemSemaphore::acquire()**

        Acquires one of the resources guarded by this semaphore, if there is one
        available, and returns `true`. If all the resources guarded by this
        semaphore have already been acquired, the call blocks until one of them
        is released by another process or thread having a semaphore with the
        same key.

        If false is returned, a system error has occurred. Call **error** () to
        get a value of **QSystemSemaphore::SystemSemaphoreError**  that
        indicates which error occurred.

        **See also** **release** ().
        """
        ...

    def key(self) -> str:
        """
        https://doc.qt.io/qt-6/qsystemsemaphore.html#key

        **QString QSystemSemaphore::key() const**

        Returns the key assigned to this system semaphore. The key is the name
        by which the semaphore can be accessed from other processes.

        **See also** **setKey** ().
        """
        ...

    def setKey(
        self,
        key: str,
        initialValue: int = ...,
        mode: "QSystemSemaphore.AccessMode" = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsystemsemaphore.html#setKey

        **void QSystemSemaphore::setKey(const QString & key , int initialValue =
        0, QSystemSemaphore::AccessMode mode = Open)**

        This function works the same as the constructor. It reconstructs this
        **QSystemSemaphore**  object. If the new **key** is different from the
        old key, calling this function is like calling the destructor of the
        semaphore with the old key, then calling the constructor to create a new
        semaphore with the new **key**. The **initialValue** and **mode**
        parameters are as defined for the constructor.

        **See also** **QSystemSemaphore** () and **key** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtMultimedia import *
import enum


class QCamera(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qcamera.html

    **Detailed Description**

    QCamera can be used within a **QMediaCaptureSession**  for video recording
    and image taking.

    You can use **QCameraDevice**  to list available cameras and choose which
    one to use.

    const **QList** <**QCameraDevice** > cameras = **QMediaDevices**
    ::videoInputs();
        for (const **QCameraDevice**  &cameraDevice : cameras)
    {
            if (cameraDevice.description() == "mycamera")
                camera =
    new **QCamera** (cameraDevice);
        }

    On hardware that supports it, QCamera lets you adjust the focus and zoom.
    This also includes functionality such as a "Macro" mode for close up work
    (e.g. reading barcodes, or recognizing letters), or "touch to focus" -
    indicating an interesting area of the image for the hardware to attempt to
    focus on.

    camera->setFocusPointMode(**QCamera** ::FocusModeManual);
    camera->setCustomFocusPoint(**QPointF** (0.25f, 0.75f)); // A point near the
    bottom left, 25% away from the corner, near that shiny vase

    The **minimumZoomFactor** () and **maximumZoomFactor** () methods provide
    the range of supported zoom factors. The **zoomTo** () method allows
    changing the zoom factor.

    camera->setZoomFactor(3.0);

    After capturing the raw data for a camera frame, the camera hardware and
    software performs various image processing tasks to produce the final image.
    This includes compensating for ambient light color, reducing noise, as well
    as making some other adjustments to the image.

    You can control many of these processing steps through the Camera
    properties. For example, you can set the white balance (or color
    temperature) used for processing images:

    camera->setWhiteBalanceMode(**QCamera** ::WhiteBalanceFluorescent);

    For more information on image processing of camera frames, see **Camera
    Image Processing** .

    See the **camera overview**  for more information.
    """

    class Feature(enum.Enum):
        ColorTemperature: QCamera = ...
        ExposureCompensation: QCamera = ...
        IsoSensitivity: QCamera = ...
        ManualExposureTime: QCamera = ...
        CustomFocusPoint: QCamera = ...
        FocusDistance: QCamera = ...

    class WhiteBalanceMode(enum.Enum):
        WhiteBalanceAuto: QCamera = ...
        WhiteBalanceManual: QCamera = ...
        WhiteBalanceSunlight: QCamera = ...
        WhiteBalanceCloudy: QCamera = ...
        WhiteBalanceShade: QCamera = ...
        WhiteBalanceTungsten: QCamera = ...
        WhiteBalanceFluorescent: QCamera = ...
        WhiteBalanceFlash: QCamera = ...
        WhiteBalanceSunset: QCamera = ...

    class ExposureMode(enum.Enum):
        ExposureAuto: QCamera = ...
        ExposureManual: QCamera = ...
        ExposurePortrait: QCamera = ...
        ExposureNight: QCamera = ...
        ExposureSports: QCamera = ...
        ExposureSnow: QCamera = ...
        ExposureBeach: QCamera = ...
        ExposureAction: QCamera = ...
        ExposureLandscape: QCamera = ...
        ExposureNightPortrait: QCamera = ...
        ExposureTheatre: QCamera = ...
        ExposureSunset: QCamera = ...
        ExposureSteadyPhoto: QCamera = ...
        ExposureFireworks: QCamera = ...
        ExposureParty: QCamera = ...
        ExposureCandlelight: QCamera = ...
        ExposureBarcode: QCamera = ...

    class TorchMode(enum.Enum):
        TorchOff: QCamera = ...
        TorchOn: QCamera = ...
        TorchAuto: QCamera = ...

    class FlashMode(enum.Enum):
        FlashOff: QCamera = ...
        FlashOn: QCamera = ...
        FlashAuto: QCamera = ...

    class FocusMode(enum.Enum):
        FocusModeAuto: QCamera = ...
        FocusModeAutoNear: QCamera = ...
        FocusModeAutoFar: QCamera = ...
        FocusModeHyperfocal: QCamera = ...
        FocusModeInfinity: QCamera = ...
        FocusModeManual: QCamera = ...

    class Error(enum.Enum):
        NoError: QCamera = ...
        CameraError: QCamera = ...

    @typing.overload
    def __init__(
        self,
        cameraDevice: "QCameraDevice",
        parent: typing.Optional[QtCore.QObject] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qcamera.html#QCamera

        **QCamera::QCamera(QObject * parent = nullptr)**

        Construct a QCamera with a **parent**.

        Selects the default camera on the system if more than one camera is
        available.
        """
        ...

    @typing.overload
    def __init__(
        self,
        position: "QCameraDevice.Position",
        parent: typing.Optional[QtCore.QObject] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qcamera.html#QCamera-1

        **QCamera::QCamera(const QCameraDevice & cameraDevice , QObject * parent
        = nullptr)**

        Construct a QCamera from a camera description **cameraDevice** and
        **parent**.
        """
        ...

    @typing.overload
    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qcamera.html#QCamera-2

        **QCamera::QCamera(QCameraDevice::Position position , QObject * parent =
        nullptr)**

        Construct a QCamera which uses a hardware camera located a the specified
        **position**.

        For example on a mobile phone it can be used to easily choose between
        front-facing and back-facing cameras.

        If no camera is available at the specified **position** or if
        **position** is **QCameraDevice::UnspecifiedPosition** , the default
        camera is used.
        """
        ...

    def manualExposureTimeChanged(self, speed: float) -> None:
        ...

    def focusPointChanged(self) -> None:
        ...

    def colorTemperatureChanged(self) -> None:
        ...

    def whiteBalanceModeChanged(self) -> None:
        ...

    def maximumZoomFactorChanged(self, a0: float) -> None:
        ...

    def minimumZoomFactorChanged(self, a0: float) -> None:
        ...

    def focusModeChanged(self) -> None:
        ...

    def supportedFeaturesChanged(self) -> None:
        ...

    def cameraFormatChanged(self) -> None:
        ...

    def cameraDeviceChanged(self) -> None:
        ...

    def errorChanged(self) -> None:
        ...

    def setColorTemperature(self, colorTemperature: int) -> None:
        """
        https://doc.qt.io/qt-6/qcamera.html#setColorTemperature

        **[slot] void QCamera::setColorTemperature(int colorTemperature )**

        Sets manual white balance to **colorTemperature**. This is used when
        **whiteBalanceMode** () is set to `WhiteBalanceManual`. The units are
        Kelvin.

        Setting a color temperature will only have an effect if
        **WhiteBalanceManual**  is supported. In this case, setting a
        temperature greater 0 will automatically set the white balance mode to
        **WhiteBalanceManual** . Setting the temperature to 0 will reset the
        white balance mode to **WhiteBalanceAuto** .

        **Note:** Setter function for property **colorTemperature** .

        **See also** **colorTemperature** ().
        """
        ...

    def setWhiteBalanceMode(self, mode: "QCamera.WhiteBalanceMode") -> None:
        """
        https://doc.qt.io/qt-6/qcamera.html#setWhiteBalanceMode

        **[slot] void QCamera::setWhiteBalanceMode(QCamera::WhiteBalanceMode
        mode )**

        Sets the white balance to **mode**.

        **Note:** Setter function for property **whiteBalanceMode** .

        **See also** **whiteBalanceMode** ().
        """
        ...

    def setAutoExposureTime(self) -> None:
        """
        https://doc.qt.io/qt-6/qcamera.html#setAutoExposureTime

        **[slot] void QCamera::setAutoExposureTime()**

        Use automatically calculated exposure time
        """
        ...

    def setManualExposureTime(self, seconds: float) -> None:
        """
        https://doc.qt.io/qt-6/qcamera.html#setManualExposureTime

        **[slot] void QCamera::setManualExposureTime(float seconds )**

        Set the manual exposure time to **seconds**

        **Note:** Setter function for property **manualExposureTime** .

        **See also** **manualExposureTime** ().
        """
        ...

    def setAutoIsoSensitivity(self) -> None:
        """
        https://doc.qt.io/qt-6/qcamera.html#setAutoIsoSensitivity

        **[slot] void QCamera::setAutoIsoSensitivity()**

        Turn on auto sensitivity
        """
        ...

    def setManualIsoSensitivity(self, iso: int) -> None:
        """
        https://doc.qt.io/qt-6/qcamera.html#manualIsoSensitivity-prop

        **manualIsoSensitivity : int**

        Describes a manually set ISO sensitivity

        Setting this property to -1 (the default), implies that the camera
        automatically adjusts the ISO sensitivity.

        **Access functions:**

        int **manualIsoSensitivity** () const
        void **setManualIsoSensitivity**
        (int **iso** )

        **Notifier signal:**

        void **manualIsoSensitivityChanged** (int)
        """
        ...

    def setExposureCompensation(self, ev: float) -> None:
        """
        https://doc.qt.io/qt-6/qcamera.html#exposureCompensation-prop

        **exposureCompensation : float**

        Exposure compensation in EV units.

        Exposure compensation property allows to adjust the automatically
        calculated exposure.

        **Access functions:**

        float **exposureCompensation** () const
        void
        **setExposureCompensation** (float **ev** )

        **Notifier signal:**

        void ****exposureCompensationChanged** ** (float **value** )
        """
        ...

    def setExposureMode(self, mode: "QCamera.ExposureMode") -> None:
        """
        https://doc.qt.io/qt-6/qcamera.html#exposureMode-prop

        **exposureMode : QCamera::ExposureMode**

        This property holds the exposure mode being used.

        **Access functions:**

        QCamera::ExposureMode **exposureMode** () const
        void
        **setExposureMode** (QCamera::ExposureMode **mode** )

        **Notifier signal:**

        void **exposureModeChanged** ()

        **See also** **QCamera::isExposureModeSupported** .
        """
        ...

    def setTorchMode(self, mode: "QCamera.TorchMode") -> None:
        """
        https://doc.qt.io/qt-6/qcamera.html#torchMode-prop

        **torchMode : QCamera::TorchMode**

        This property holds the torch mode being used.

        A torch is a continuous source of light. It can be used during video
        recording in low light conditions. Enabling torch mode will usually
        override any currently set flash mode.

        **Access functions:**

        QCamera::TorchMode **torchMode** () const
        void **setTorchMode**
        (QCamera::TorchMode **mode** )

        **Notifier signal:**

        void **torchModeChanged** ()

        **See also** **QCamera::TorchMode** , **QCamera::isTorchModeSupported**
        , and **QCamera::flashMode** .
        """
        ...

    def setFlashMode(self, mode: "QCamera.FlashMode") -> None:
        """
        https://doc.qt.io/qt-6/qcamera.html#flashMode-prop

        **flashMode : QCamera::FlashMode**

        This property holds the flash mode being used.

        Enables a certain flash mode if the camera has a flash.

        **Access functions:**

        QCamera::FlashMode **flashMode** () const
        void **setFlashMode**
        (QCamera::FlashMode **mode** )

        **Notifier signal:**

        void **flashModeChanged** ()

        **See also** **QCamera::FlashMode** , **QCamera::isFlashModeSupported**
        , and **QCamera::isFlashReady** .
        """
        ...

    def zoomTo(self, zoom: float, rate: float) -> None:
        """
        https://doc.qt.io/qt-6/qcamera.html#zoomTo

        **[slot] void QCamera::zoomTo(float factor , float rate )**

        Zooms to a zoom factor **factor** using **rate**.

        The **rate** is specified in powers of two per second. At a rate of 1 it
        would take 2 seconds to go from a zoom factor of 1 to 4.

        **Note:** Using a specific rate is not supported on all cameras. If not
        supported, zooming will happen as fast as possible.
        """
        ...

    def stop(self) -> None:
        """
        https://doc.qt.io/qt-6/qcamera.html#stop

        **[slot] void QCamera::stop()**

        Stops the camera. Same as **setActive** (false).
        """
        ...

    def start(self) -> None:
        """
        https://doc.qt.io/qt-6/qcamera.html#start

        **[slot] void QCamera::start()**

        Starts the camera.

        Same as **setActive** (true).

        If the camera can't be started for some reason, the **errorOccurred** ()
        signal is emitted.
        """
        ...

    def setActive(self, active: bool) -> None:
        """
        https://doc.qt.io/qt-6/qcamera.html#setActive

        **[slot] void QCamera::setActive(bool active )**

        Turns the camera on if **active** is `true`, or off if it's `false`.

        **Note:** Setter function for property **active** .

        **See also** **isActive** ().
        """
        ...

    def colorTemperature(self) -> int:
        """
        https://doc.qt.io/qt-6/qcamera.html#colorTemperature

        **int QCamera::colorTemperature() const**

        Returns the current color temperature if the current white balance mode
        is `WhiteBalanceManual`. For other modes the return value is undefined.

        **Note:** Getter function for property colorTemperature.

        **See also** **setColorTemperature** ().
        """
        ...

    def isWhiteBalanceModeSupported(self, mode: "QCamera.WhiteBalanceMode") -> bool:
        """
        https://doc.qt.io/qt-6/qcamera.html#isWhiteBalanceModeSupported

        **[invokable] bool
        QCamera::isWhiteBalanceModeSupported(QCamera::WhiteBalanceMode mode )
        const**

        Returns true if the white balance **mode** is supported.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def whiteBalanceMode(self) -> "QCamera.WhiteBalanceMode":
        """
        https://doc.qt.io/qt-6/qcamera.html#whiteBalanceMode

        **QCamera::WhiteBalanceMode QCamera::whiteBalanceMode() const**

        Returns the white balance mode being used.

        **Note:** Getter function for property whiteBalanceMode.

        **See also** **setWhiteBalanceMode** ().
        """
        ...

    def maximumExposureTime(self) -> float:
        """
        https://doc.qt.io/qt-6/qcamera.html#maximumExposureTime

        **float QCamera::maximumExposureTime() const**

        The maximal exposure time in seconds.
        """
        ...

    def minimumExposureTime(self) -> float:
        """
        https://doc.qt.io/qt-6/qcamera.html#minimumExposureTime

        **float QCamera::minimumExposureTime() const**

        The minimal exposure time in seconds.
        """
        ...

    def maximumIsoSensitivity(self) -> int:
        """
        https://doc.qt.io/qt-6/qcamera.html#maximumIsoSensitivity

        **int QCamera::maximumIsoSensitivity() const**

        Returns the maximum ISO sensitivity supported by the camera.
        """
        ...

    def minimumIsoSensitivity(self) -> int:
        """
        https://doc.qt.io/qt-6/qcamera.html#minimumIsoSensitivity

        **int QCamera::minimumIsoSensitivity() const**

        Returns the minimum ISO sensitivity supported by the camera.
        """
        ...

    def manualExposureTime(self) -> float:
        """
        https://doc.qt.io/qt-6/qcamera.html#manualExposureTime

        **float QCamera::manualExposureTime() const**

        Returns the manual exposure time in seconds, or -1 if the camera is
        using automatic exposure times.

        **Note:** Getter function for property manualExposureTime.

        **See also** **setManualExposureTime** ().
        """
        ...

    def exposureTime(self) -> float:
        """
        https://doc.qt.io/qt-6/qcamera.html#exposureTime

        **float QCamera::exposureTime() const**

        Returns the current exposure time in seconds.

        **Note:** Getter function for property exposureTime.
        """
        ...

    def manualIsoSensitivity(self) -> int:
        """
        https://doc.qt.io/qt-6/qcamera.html#manualIsoSensitivity-prop

        **manualIsoSensitivity : int**

        Describes a manually set ISO sensitivity

        Setting this property to -1 (the default), implies that the camera
        automatically adjusts the ISO sensitivity.

        **Access functions:**

        int **manualIsoSensitivity** () const
        void **setManualIsoSensitivity**
        (int **iso** )

        **Notifier signal:**

        void **manualIsoSensitivityChanged** (int)
        """
        ...

    def isoSensitivity(self) -> int:
        """
        https://doc.qt.io/qt-6/qcamera.html#isoSensitivity-prop

        **[read-only] isoSensitivity : const int**

        This property holds the sensor ISO sensitivity.

        Describes the ISO sensitivity currently used by the camera.

        **Access functions:**

        int **isoSensitivity** () const

        **Notifier signal:**

        void ****isoSensitivityChanged** ** (int **value** )

        **See also** **setAutoIsoSensitivity** () and
        **setManualIsoSensitivity** ().
        """
        ...

    def exposureCompensation(self) -> float:
        """
        https://doc.qt.io/qt-6/qcamera.html#exposureCompensation-prop

        **exposureCompensation : float**

        Exposure compensation in EV units.

        Exposure compensation property allows to adjust the automatically
        calculated exposure.

        **Access functions:**

        float **exposureCompensation** () const
        void
        **setExposureCompensation** (float **ev** )

        **Notifier signal:**

        void ****exposureCompensationChanged** ** (float **value** )
        """
        ...

    def isExposureModeSupported(self, mode: "QCamera.ExposureMode") -> bool:
        """
        https://doc.qt.io/qt-6/qcamera.html#isExposureModeSupported

        **[invokable] bool
        QCamera::isExposureModeSupported(QCamera::ExposureMode mode ) const**

        Returns true if the exposure **mode** is supported.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def exposureMode(self) -> "QCamera.ExposureMode":
        """
        https://doc.qt.io/qt-6/qcamera.html#exposureMode-prop

        **exposureMode : QCamera::ExposureMode**

        This property holds the exposure mode being used.

        **Access functions:**

        QCamera::ExposureMode **exposureMode** () const
        void
        **setExposureMode** (QCamera::ExposureMode **mode** )

        **Notifier signal:**

        void **exposureModeChanged** ()

        **See also** **QCamera::isExposureModeSupported** .
        """
        ...

    def isTorchModeSupported(self, mode: "QCamera.TorchMode") -> bool:
        """
        https://doc.qt.io/qt-6/qcamera.html#isTorchModeSupported

        **[invokable] bool QCamera::isTorchModeSupported(QCamera::TorchMode mode
        ) const**

        Returns true if the torch **mode** is supported.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def torchMode(self) -> "QCamera.TorchMode":
        """
        https://doc.qt.io/qt-6/qcamera.html#torchMode-prop

        **torchMode : QCamera::TorchMode**

        This property holds the torch mode being used.

        A torch is a continuous source of light. It can be used during video
        recording in low light conditions. Enabling torch mode will usually
        override any currently set flash mode.

        **Access functions:**

        QCamera::TorchMode **torchMode** () const
        void **setTorchMode**
        (QCamera::TorchMode **mode** )

        **Notifier signal:**

        void **torchModeChanged** ()

        **See also** **QCamera::TorchMode** , **QCamera::isTorchModeSupported**
        , and **QCamera::flashMode** .
        """
        ...

    def isFlashReady(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcamera.html#isFlashReady

        **[invokable] bool QCamera::isFlashReady() const**

        Returns true if flash is charged.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .

        **Note:** Getter function for property **flashReady** .
        """
        ...

    def isFlashModeSupported(self, mode: "QCamera.FlashMode") -> bool:
        """
        https://doc.qt.io/qt-6/qcamera.html#isFlashModeSupported

        **[invokable] bool QCamera::isFlashModeSupported(QCamera::FlashMode mode
        ) const**

        Returns true if the flash **mode** is supported.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def flashMode(self) -> "QCamera.FlashMode":
        """
        https://doc.qt.io/qt-6/qcamera.html#flashMode-prop

        **flashMode : QCamera::FlashMode**

        This property holds the flash mode being used.

        Enables a certain flash mode if the camera has a flash.

        **Access functions:**

        QCamera::FlashMode **flashMode** () const
        void **setFlashMode**
        (QCamera::FlashMode **mode** )

        **Notifier signal:**

        void **flashModeChanged** ()

        **See also** **QCamera::FlashMode** , **QCamera::isFlashModeSupported**
        , and **QCamera::isFlashReady** .
        """
        ...

    def setZoomFactor(self, factor: float) -> None:
        """
        https://doc.qt.io/qt-6/qcamera.html#setZoomFactor

        **void QCamera::setZoomFactor(float factor )**

        Zooms to a zoom factor **factor** at a rate of 1 factor per second.

        **Note:** Setter function for property **zoomFactor** .

        **See also** **zoomFactor** ().
        """
        ...

    def zoomFactor(self) -> float:
        """
        https://doc.qt.io/qt-6/qcamera.html#zoomFactor-prop

        **zoomFactor : float**

        This property holds the current zoom factor.

        Gets or sets the current zoom factor. Values will be clamped between
        **minimumZoomFactor**  and **maximumZoomFactor** .

        **Access functions:**

        float **zoomFactor** () const
        void ****setZoomFactor** ** (float
        **factor** )

        **Notifier signal:**

        void **zoomFactorChanged** (float)

        **Member Function Documentation**
        """
        ...

    def maximumZoomFactor(self) -> float:
        """
        https://doc.qt.io/qt-6/qcamera.html#maximumZoomFactor

        **float QCamera::maximumZoomFactor() const**

        Returns the maximum zoom factor.

        This will be `1.0` on cameras that do not support zooming.

        **Note:** Getter function for property maximumZoomFactor.
        """
        ...

    def minimumZoomFactor(self) -> float:
        """
        https://doc.qt.io/qt-6/qcamera.html#minimumZoomFactor

        **float QCamera::minimumZoomFactor() const**

        Returns the minimum zoom factor.

        This will be `1.0` on cameras that do not support zooming.

        **Note:** Getter function for property minimumZoomFactor.
        """
        ...

    def focusDistance(self) -> float:
        """
        https://doc.qt.io/qt-6/qcamera.html#focusDistance-prop

        **focusDistance : float**

        This property return an approximate focus distance of the camera. The
        value reported is between 0 and 1, 0 being the closest possible focus
        distance, 1 being as far away as possible. Note that 1 is often, but not
        always infinity.

        Setting the focus distance will be ignored unless the focus mode is set
        to **FocusModeManual** .

        **Access functions:**

        float **focusDistance** () const
        void **setFocusDistance** (float
        **d** )

        **Notifier signal:**

        void **focusDistanceChanged** (float)
        """
        ...

    def setFocusDistance(self, d: float) -> None:
        """
        https://doc.qt.io/qt-6/qcamera.html#focusDistance-prop

        **focusDistance : float**

        This property return an approximate focus distance of the camera. The
        value reported is between 0 and 1, 0 being the closest possible focus
        distance, 1 being as far away as possible. Note that 1 is often, but not
        always infinity.

        Setting the focus distance will be ignored unless the focus mode is set
        to **FocusModeManual** .

        **Access functions:**

        float **focusDistance** () const
        void **setFocusDistance** (float
        **d** )

        **Notifier signal:**

        void **focusDistanceChanged** (float)
        """
        ...

    def setCustomFocusPoint(self, point: QtCore.QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qcamera.html#customFocusPoint-prop

        **customFocusPoint : QPointF**

        This property represents the position of the custom focus point, in
        relative frame coordinates: **QPointF** (0,0) points to the left top
        frame point, **QPointF** (0.5,0.5) points to the frame center.

        The custom focus point property is used only in `FocusPointCustom` focus
        mode.

        You can check whether custom focus points are supported by querying
        **supportedFeatures** () with the Feature.**CustomFocusPoint**  flag.

        **Access functions:**

        QPointF **customFocusPoint** () const
        void **setCustomFocusPoint**
        (const QPointF & **point** )

        **Notifier signal:**

        void **customFocusPointChanged** ()
        """
        ...

    def customFocusPoint(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qcamera.html#customFocusPoint-prop

        **customFocusPoint : QPointF**

        This property represents the position of the custom focus point, in
        relative frame coordinates: **QPointF** (0,0) points to the left top
        frame point, **QPointF** (0.5,0.5) points to the frame center.

        The custom focus point property is used only in `FocusPointCustom` focus
        mode.

        You can check whether custom focus points are supported by querying
        **supportedFeatures** () with the Feature.**CustomFocusPoint**  flag.

        **Access functions:**

        QPointF **customFocusPoint** () const
        void **setCustomFocusPoint**
        (const QPointF & **point** )

        **Notifier signal:**

        void **customFocusPointChanged** ()
        """
        ...

    def focusPoint(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qcamera.html#focusPoint

        **QPointF QCamera::focusPoint() const**

        Returns the point currently used by the auto focus system to focus onto.

        **Note:** Getter function for property focusPoint.
        """
        ...

    def isFocusModeSupported(self, mode: "QCamera.FocusMode") -> bool:
        """
        https://doc.qt.io/qt-6/qcamera.html#isFocusModeSupported

        **[invokable] bool QCamera::isFocusModeSupported(QCamera::FocusMode mode
        ) const**

        Returns true if the focus **mode** is supported by the camera.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def setFocusMode(self, mode: "QCamera.FocusMode") -> None:
        """
        https://doc.qt.io/qt-6/qcamera.html#focusMode-prop

        **focusMode : FocusMode**

        This property holds the current camera focus mode.

        Sets up different focus modes for the camera. All auto focus modes will
        focus continuously. Locking the focus is possible by setting the focus
        mode to **FocusModeManual** . This will keep the current focus and stop
        any automatic focusing.

        **Access functions:**

        QCamera::FocusMode **focusMode** () const
        void **setFocusMode**
        (QCamera::FocusMode **mode** )

        **See also** **isFocusModeSupported** .
        """
        ...

    def focusMode(self) -> "QCamera.FocusMode":
        """
        https://doc.qt.io/qt-6/qcamera.html#focusMode-prop

        **focusMode : FocusMode**

        This property holds the current camera focus mode.

        Sets up different focus modes for the camera. All auto focus modes will
        focus continuously. Locking the focus is possible by setting the focus
        mode to **FocusModeManual** . This will keep the current focus and stop
        any automatic focusing.

        **Access functions:**

        QCamera::FocusMode **focusMode** () const
        void **setFocusMode**
        (QCamera::FocusMode **mode** )

        **See also** **isFocusModeSupported** .
        """
        ...

    def supportedFeatures(self) -> "QCamera.Feature":
        """
        https://doc.qt.io/qt-6/qcamera.html#supportedFeatures

        **QCamera::Features QCamera::supportedFeatures() const**

        Returns the features supported by this camera.

        **Note:** Getter function for property supportedFeatures.

        **See also** **QCamera::Feature** .
        """
        ...

    def errorString(self) -> str:
        """
        https://doc.qt.io/qt-6/qcamera.html#errorString

        **QString QCamera::errorString() const**

        Returns a human readable string describing a camera's error state.

        **Note:** Getter function for property errorString.
        """
        ...

    def error(self) -> "QCamera.Error":
        """
        https://doc.qt.io/qt-6/qcamera.html#error

        **QCamera::Error QCamera::error() const**

        Returns the error state of the camera.

        **Note:** Getter function for property error.
        """
        ...

    def setCameraFormat(self, format: "QCameraFormat") -> None:
        """
        https://doc.qt.io/qt-6/qcamera.html#setCameraFormat

        **void QCamera::setCameraFormat(const QCameraFormat & format )**

        Tells the camera to use the format desribed by **format**. This can be
        used to define as specific resolution and frame rate to be used for
        recording and image capture.

        **Note:** Setter function for property **cameraFormat** .

        **See also** **cameraFormat** ().
        """
        ...

    def cameraFormat(self) -> "QCameraFormat":
        """
        https://doc.qt.io/qt-6/qcamera.html#cameraFormat

        **QCameraFormat QCamera::cameraFormat() const**

        Returns the camera format currently used by the camera.

        **Note:** Getter function for property cameraFormat.

        **See also** **setCameraFormat** () and **QCameraDevice::videoFormats**
        .
        """
        ...

    def setCameraDevice(self, cameraDevice: "QCameraDevice") -> None:
        """
        https://doc.qt.io/qt-6/qcamera.html#setCameraDevice

        **void QCamera::setCameraDevice(const QCameraDevice & cameraDevice )**

        Connects the camera object to the physical camera device described by
        **cameraDevice**. Using a default constructed **QCameraDevice**  object
        as **cameraDevice** will connect the camera to the system default camera
        device.

        **Note:** Setter function for property **cameraDevice** .

        **See also** **cameraDevice** ().
        """
        ...

    def cameraDevice(self) -> "QCameraDevice":
        """
        https://doc.qt.io/qt-6/qcamera.html#cameraDevice

        **QCameraDevice QCamera::cameraDevice() const**

        Returns the **QCameraDevice**  object associated with this camera.

        **Note:** Getter function for property cameraDevice.

        **See also** **setCameraDevice** ().
        """
        ...

    def captureSession(self) -> "QMediaCaptureSession":
        """
        https://doc.qt.io/qt-6/qcamera.html#captureSession

        **QMediaCaptureSession *QCamera::captureSession() const**

        Returns the capture session this camera is connected to, or a nullptr if
        the camera is not connected to a capture session.

        use **QMediaCaptureSession::setCamera** () to connect the camera to a
        session.
        """
        ...

    def isActive(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcamera.html#isActive

        **bool QCamera::isActive() const**

        Returns true if the camera is currently active.

        **Note:** Getter function for property **active** .
        """
        ...

    def isAvailable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcamera.html#isAvailable

        **bool QCamera::isAvailable() const**

        Returns true if the camera can be used.
        """
        ...

    @property
    def activeChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def customFocusPointChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def errorOccurred(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qcamera.html#errorOccurred

        **[signal] void QCamera::errorOccurred(QCamera::Error error , const
        QString & errorString )**

        This signal is emitted when error state changes to **error**. A
        description of the error is provided as **errorString**.
        """
        ...

    @property
    def exposureCompensationChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qcamera.html#exposureCompensationChanged

        **[signal] void QCamera::exposureCompensationChanged(float value )**

        Signal emitted when the exposure compensation changes to **value**.

        **Note:** Notifier signal for property **exposureCompensation** .
        """
        ...

    @property
    def exposureModeChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def exposureTimeChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qcamera.html#exposureTimeChanged

        **[signal] void QCamera::exposureTimeChanged(float speed )**

        Signals that a camera's exposure **speed** has changed.

        **Note:** Notifier signal for property **exposureTime** .
        """
        ...

    @property
    def flashModeChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def flashReady(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qcamera.html#flashReady

        **[signal] void QCamera::flashReady(bool ready )**

        Signal the flash **ready** status has changed.

        **Note:** Notifier signal for property flashReady.
        """
        ...

    @property
    def focusDistanceChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def isoSensitivityChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qcamera.html#isoSensitivityChanged

        **[signal] void QCamera::isoSensitivityChanged(int value )**

        Signal emitted when sensitivity changes to **value**.

        **Note:** Notifier signal for property **isoSensitivity** .
        """
        ...

    @property
    def manualIsoSensitivityChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def torchModeChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def zoomFactorChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtNetwork import *


class QNetworkDiskCache(QAbstractNetworkCache):
    """
    https://doc.qt.io/qt-6/qnetworkdiskcache.html

    **Detailed Description**

    QNetworkDiskCache stores each url in its own file inside of the
    **cacheDirectory**  using **QDataStream** . Files with a text MimeType are
    compressed using **qCompress** . Data is written to disk only in **insert**
    () and **updateMetaData** ().

    Currently you cannot share the same cache files with more than one disk
    cache.

    QNetworkDiskCache by default limits the amount of space that the cache will
    use on the system to 50MB.

    Note you have to set the cache directory before it will work.

    A network disk cache can be enabled by:

    **QNetworkAccessManager**  *manager = new **QNetworkAccessManager** (this);
    **QNetworkDiskCache**  *diskCache = new **QNetworkDiskCache** (this);
    diskCache->setCacheDirectory("cacheDir");
        manager->setCache(diskCache);

    When sending requests, to control the preference of when to use the cache
    and when to use the network, consider the following:

    // do a normal request (preferred from network, as this is the default)
    **QNetworkRequest**  request(**QUrl** (**QString** ("http://qt-
    project.org")));
        manager->get(request);

        // do a request
    preferred from cache
        **QNetworkRequest**  request2(**QUrl** (**QString**
    ("http://qt-project.org")));
        request2.setAttribute(**QNetworkRequest**
    ::CacheLoadControlAttribute, **QNetworkRequest** ::PreferCache);
    manager->get(request2);

    To check whether the response came from the cache or from the network, the
    following can be applied:

    void replyFinished(**QNetworkReply**  *reply) {
            **QVariant**
    fromCache = reply->attribute(**QNetworkRequest**
    ::SourceIsFromCacheAttribute);
            **qDebug** () << "page from cache?"
    << fromCache.toBool();
        }
    """

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkdiskcache.html#QNetworkDiskCache

        **QNetworkDiskCache::QNetworkDiskCache(QObject * parent = nullptr)**

        Creates a new disk cache. The **parent** argument is passed to
        **QAbstractNetworkCache** 's constructor.
        """
        ...

    def expire(self) -> int:
        """
        https://doc.qt.io/qt-6/qnetworkdiskcache.html#expire

        **[virtual protected] qint64 QNetworkDiskCache::expire()**

        Cleans the cache so that its size is under the maximum cache size.
        Returns the current size of the cache.

        When the current size of the cache is greater than the
        **maximumCacheSize** () older cache files are removed until the total
        size is less then 90% of **maximumCacheSize** () starting with the
        oldest ones first using the file creation date to determine how old a
        cache file is.

        Subclasses can reimplement this function to change the order that cache
        files are removed taking into account information in the application
        knows about that **QNetworkDiskCache**  does not, for example the number
        of times a cache is accessed.

        **Note:****cacheSize** () calls expire if the current cache size is
        unknown.

        **See also** **maximumCacheSize** () and **fileMetaData** ().
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkdiskcache.html#clear

        **[override virtual slot] void QNetworkDiskCache::clear()**

        Reimplements: **QAbstractNetworkCache::clear** ().
        """
        ...

    def fileMetaData(self, fileName: str) -> QNetworkCacheMetaData:
        """
        https://doc.qt.io/qt-6/qnetworkdiskcache.html#fileMetaData

        **QNetworkCacheMetaData QNetworkDiskCache::fileMetaData(const QString &
        fileName ) const**

        Returns the **QNetworkCacheMetaData**  for the cache file **fileName**.

        If **fileName** is not a cache file **QNetworkCacheMetaData**  will be
        invalid.
        """
        ...

    def insert(self, device: QtCore.QIODevice) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkdiskcache.html#insert

        **[override virtual] void QNetworkDiskCache::insert(QIODevice * device
        )**

        Reimplements: **QAbstractNetworkCache::insert** (QIODevice *device).
        """
        ...

    def prepare(self, metaData: QNetworkCacheMetaData) -> QtCore.QIODevice:
        """
        https://doc.qt.io/qt-6/qnetworkdiskcache.html#prepare

        **[override virtual] QIODevice *QNetworkDiskCache::prepare(const
        QNetworkCacheMetaData & metaData )**

        Reimplements: **QAbstractNetworkCache::prepare** (const
        QNetworkCacheMetaData &metaData).
        """
        ...

    def remove(self, url: QtCore.QUrl) -> bool:
        """
        https://doc.qt.io/qt-6/qnetworkdiskcache.html#remove

        **[override virtual] bool QNetworkDiskCache::remove(const QUrl & url )**

        Reimplements: **QAbstractNetworkCache::remove** (const QUrl &url).
        """
        ...

    def data(self, url: QtCore.QUrl) -> QtCore.QIODevice:
        """
        https://doc.qt.io/qt-6/qnetworkdiskcache.html#data

        **[override virtual] QIODevice *QNetworkDiskCache::data(const QUrl & url
        )**

        Reimplements: **QAbstractNetworkCache::data** (const QUrl &url).
        """
        ...

    def updateMetaData(self, metaData: QNetworkCacheMetaData) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkdiskcache.html#updateMetaData

        **[override virtual] void QNetworkDiskCache::updateMetaData(const
        QNetworkCacheMetaData & metaData )**

        Reimplements: **QAbstractNetworkCache::updateMetaData** (const
        QNetworkCacheMetaData &metaData).
        """
        ...

    def metaData(self, url: QtCore.QUrl) -> QNetworkCacheMetaData:
        """
        https://doc.qt.io/qt-6/qnetworkdiskcache.html#metaData

        **[override virtual] QNetworkCacheMetaData
        QNetworkDiskCache::metaData(const QUrl & url )**

        Reimplements: **QAbstractNetworkCache::metaData** (const QUrl &url).
        """
        ...

    def cacheSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qnetworkdiskcache.html#cacheSize

        **[override virtual] qint64 QNetworkDiskCache::cacheSize() const**

        Reimplements: **QAbstractNetworkCache::cacheSize() const** .
        """
        ...

    def setMaximumCacheSize(self, size: int) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkdiskcache.html#setMaximumCacheSize

        **void QNetworkDiskCache::setMaximumCacheSize(qint64 size )**

        Sets the maximum size of the disk cache to be **size**.

        If the new size is smaller then the current cache size then the cache
        will call **expire** ().

        **See also** **maximumCacheSize** ().
        """
        ...

    def maximumCacheSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qnetworkdiskcache.html#maximumCacheSize

        **qint64 QNetworkDiskCache::maximumCacheSize() const**

        Returns the current maximum size for the disk cache.

        **See also** **setMaximumCacheSize** ().
        """
        ...

    def setCacheDirectory(self, cacheDir: str) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkdiskcache.html#setCacheDirectory

        **void QNetworkDiskCache::setCacheDirectory(const QString & cacheDir )**

        Sets the directory where cached files will be stored to **cacheDir**

        **QNetworkDiskCache**  will create this directory if it does not exists.

        Prepared cache items will be stored in the new cache directory when they
        are inserted.

        **See also** **cacheDirectory** () and **QStandardPaths::CacheLocation**
        .
        """
        ...

    def cacheDirectory(self) -> str:
        """
        https://doc.qt.io/qt-6/qnetworkdiskcache.html#cacheDirectory

        **QString QNetworkDiskCache::cacheDirectory() const**

        Returns the location where cached files will be stored.

        **See also** **setCacheDirectory** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtCore


class QFocusEvent(QtCore.QEvent):
    """
    https://doc.qt.io/qt-6/qfocusevent.html

    **Detailed Description**

    Focus events are sent to widgets when the keyboard input focus changes.
    Focus events occur due to mouse actions, key presses (such as **Tab** or
    **Backtab** ), the window system, popup menus, keyboard shortcuts, or other
    application-specific reasons. The reason for a particular focus event is
    returned by **reason** () in the appropriate event handler.

    The event handlers **QWidget::focusInEvent** (), **QWidget::focusOutEvent**
    (), **QGraphicsItem::focusInEvent**  and **QGraphicsItem::focusOutEvent** ()
    receive focus events.

    **See also** **QWidget::setFocus** (), **QWidget::setFocusPolicy** (), and
    **Keyboard Focus in Widgets** .
    """

    def __init__(
        self, type: QtCore.QEvent.Type, reason: QtCore.Qt.FocusReason = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qfocusevent.html#QFocusEvent-2

        **QFocusEvent::QFocusEvent(QEvent::Type type , Qt::FocusReason reason =
        Qt::OtherFocusReason)**

        Constructs a focus event object.

        The **type** parameter must be either **QEvent::FocusIn**  or
        **QEvent::FocusOut** . The **reason** describes the cause of the change
        in focus.
        """
        ...

    def clone(self) -> "QFocusEvent":
        ...

    def reason(self) -> QtCore.Qt.FocusReason:
        """
        https://doc.qt.io/qt-6/qfocusevent.html#reason

        **Qt::FocusReason QFocusEvent::reason() const**

        Returns the reason for this focus event.
        """
        ...

    def lostFocus(self) -> bool:
        """
        https://doc.qt.io/qt-6/qfocusevent.html#lostFocus

        **bool QFocusEvent::lostFocus() const**

        Returns `true` if **type** () is **QEvent::FocusOut** ; otherwise
        returns false.
        """
        ...

    def gotFocus(self) -> bool:
        """
        https://doc.qt.io/qt-6/qfocusevent.html#gotFocus

        **bool QFocusEvent::gotFocus() const**

        Returns `true` if **type** () is **QEvent::FocusIn** ; otherwise returns
        false.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QVersionNumber(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qversionnumber.html

    **Detailed Description**

    **QVersionNumber**  version(1, 2, 3);  // 1.2.3
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qversionnumber.html#QVersionNumber

        **QVersionNumber::QVersionNumber()**

        Produces a null version.

        **See also** **isNull** ().
        """
        ...

    @typing.overload
    def __init__(self, seg: typing.Iterable[int]) -> None:
        """
        https://doc.qt.io/qt-6/qversionnumber.html#QVersionNumber-1

        **QVersionNumber::QVersionNumber(const QList<int> & seg )**

        Constructs a version number from the list of numbers contained in
        **seg**.
        """
        ...

    @typing.overload
    def __init__(self, maj: int) -> None:
        """
        https://doc.qt.io/qt-6/qversionnumber.html#QVersionNumber-2

        **QVersionNumber::QVersionNumber(QList<int> && seg )**

        Move-constructs a version number from the list of numbers contained in
        **seg**.

        This constructor is only enabled if the compiler supports C++11 move
        semantics.
        """
        ...

    @typing.overload
    def __init__(self, maj: int, min: int) -> None:
        """
        https://doc.qt.io/qt-6/qversionnumber.html#QVersionNumber-3

        **QVersionNumber::QVersionNumber(std::initializer_list<int> args )**

        Construct a version number from the std::initializer_list specified by
        **args**.

        This constructor is only enabled if the compiler supports C++11
        initializer lists.
        """
        ...

    @typing.overload
    def __init__(self, maj: int, min: int, mic: int) -> None:
        """
        https://doc.qt.io/qt-6/qversionnumber.html#QVersionNumber-4

        **QVersionNumber::QVersionNumber(int maj )**

        Constructs a QVersionNumber consisting of just the major version number
        **maj**.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QVersionNumber") -> None:
        """
        https://doc.qt.io/qt-6/qversionnumber.html#QVersionNumber-5

        **QVersionNumber::QVersionNumber(int maj , int min )**

        Constructs a QVersionNumber consisting of the major and minor version
        numbers **maj** and **min** , respectively.
        """
        ...

    def __hash__(self) -> int:
        ...

    @staticmethod
    def fromString(string: str) -> typing.Tuple["QVersionNumber", int]:
        """
        https://doc.qt.io/qt-6/qversionnumber.html#fromString

        **[static] QVersionNumber QVersionNumber::fromString(const QString &
        string , int * suffixIndex = nullptr)**

        Constructs a **QVersionNumber**  from a specially formatted **string**
        of non-negative decimal numbers delimited by a period (`.`).

        Once the numerical segments have been parsed, the remainder of the
        string is considered to be the suffix string. The start index of that
        string will be stored in **suffixIndex** if it is not null.

        **QString**  string("5.4.0-alpha");
            int suffixIndex;
        **QVersionNumber**  version = **QVersionNumber** ::fromString(string,
        &suffixIndex);
            // version is 5.4.0
            // suffixIndex is 5

        **See also** **isNull** ().
        """
        ...

    def toString(self) -> str:
        """
        https://doc.qt.io/qt-6/qversionnumber.html#toString

        **QString QVersionNumber::toString() const**

        Returns a string with all of the segments delimited by a period (`.`).

        **See also** **majorVersion** (), **minorVersion** (), **microVersion**
        (), and **segments** ().
        """
        ...

    @staticmethod
    def commonPrefix(v1: "QVersionNumber", v2: "QVersionNumber") -> "QVersionNumber":
        """
        https://doc.qt.io/qt-6/qversionnumber.html#commonPrefix

        **[static] QVersionNumber QVersionNumber::commonPrefix(const
        QVersionNumber & v1 , const QVersionNumber & v2 )**

        **QVersionNumber**  QVersionNumber::commonPrefix(const
        **QVersionNumber**  &v1, const **QVersionNumber**  &v2)

        Returns a version number that is a parent version of both **v1** and
        **v2**.

        **See also** **isPrefixOf** ().
        """
        ...

    @staticmethod
    def compare(v1: "QVersionNumber", v2: "QVersionNumber") -> int:
        """
        https://doc.qt.io/qt-6/qversionnumber.html#compare

        **[static] int QVersionNumber::compare(const QVersionNumber & v1 , const
        QVersionNumber & v2 )**

        Compares **v1** with **v2** and returns an integer less than, equal to,
        or greater than zero, depending on whether **v1** is less than, equal
        to, or greater than **v2** , respectively.

        Comparisons are performed by comparing the segments of **v1** and **v2**
        starting at index 0 and working towards the end of the longer list.

        **QVersionNumber**  v1(1, 2);
            **QVersionNumber**  v2(1, 2, 0);
        int compare = **QVersionNumber** ::compare(v1, v2); // compare == -1
        """
        ...

    def isPrefixOf(self, other: "QVersionNumber") -> bool:
        """
        https://doc.qt.io/qt-6/qversionnumber.html#isPrefixOf

        **bool QVersionNumber::isPrefixOf(const QVersionNumber & other ) const**

        Returns `true` if the current version number is contained in the
        **other** version number, otherwise returns `false`.

        **QVersionNumber**  v1(5, 3);
            **QVersionNumber**  v2(5, 3, 1);
        bool value = v1.isPrefixOf(v2); // true

        **See also** **commonPrefix** ().
        """
        ...

    def segmentCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qversionnumber.html#segmentCount

        **int QVersionNumber::segmentCount() const**

        Returns the number of integers stored in **segments** ().

        **See also** **segments** ().
        """
        ...

    def segmentAt(self, index: int) -> int:
        """
        https://doc.qt.io/qt-6/qversionnumber.html#segmentAt

        **int QVersionNumber::segmentAt(int index ) const**

        Returns the segment value at **index**. If the index does not exist,
        returns 0.

        **See also** **segments** () and **segmentCount** ().
        """
        ...

    def segments(self) -> typing.List[int]:
        """
        https://doc.qt.io/qt-6/qversionnumber.html#segments

        **QList<int> QVersionNumber::segments() const**

        Returns all of the numerical segments.

        **See also** **majorVersion** (), **minorVersion** (), and
        **microVersion** ().
        """
        ...

    def normalized(self) -> "QVersionNumber":
        """
        https://doc.qt.io/qt-6/qversionnumber.html#normalized

        **QVersionNumber QVersionNumber::normalized() const**

        Returns an equivalent version number but with all trailing zeros
        removed.

        To check if two numbers are equivalent, use normalized() on both version
        numbers before performing the compare.

        **QVersionNumber**  v1(5, 4);
            **QVersionNumber**  v2(5, 4, 0);
        bool equivalent = v1.normalized() == v2.normalized();
            bool equal =
        v1 == v2;
            // equivalent is true
            // equal is false
        """
        ...

    def microVersion(self) -> int:
        """
        https://doc.qt.io/qt-6/qversionnumber.html#microVersion

        **int QVersionNumber::microVersion() const**

        Returns the micro version number, that is, the third segment. This
        function is equivalent to **segmentAt** (2). If this **QVersionNumber**
        object does not contain a micro number, this function returns 0.

        **See also** **isNull** () and **segmentAt** ().
        """
        ...

    def minorVersion(self) -> int:
        """
        https://doc.qt.io/qt-6/qversionnumber.html#minorVersion

        **int QVersionNumber::minorVersion() const**

        Returns the minor version number, that is, the second segment. This
        function is equivalent to **segmentAt** (1). If this **QVersionNumber**
        object does not contain a minor number, this function returns 0.

        **See also** **isNull** () and **segmentAt** ().
        """
        ...

    def majorVersion(self) -> int:
        """
        https://doc.qt.io/qt-6/qversionnumber.html#majorVersion

        **int QVersionNumber::majorVersion() const**

        Returns the major version number, that is, the first segment. This
        function is equivalent to **segmentAt** (0). If this **QVersionNumber**
        object is null, this function returns 0.

        **See also** **isNull** () and **segmentAt** ().
        """
        ...

    def isNormalized(self) -> bool:
        """
        https://doc.qt.io/qt-6/qversionnumber.html#isNormalized

        **bool QVersionNumber::isNormalized() const**

        Returns `true` if the version number does not contain any trailing
        zeros, otherwise returns `false`.

        **See also** **normalized** ().
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qversionnumber.html#isNull

        **bool QVersionNumber::isNull() const**

        Returns `true` if there are zero numerical segments, otherwise returns
        `false`.

        **See also** **segments** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtGui import *


class QTextImageFormat(QTextCharFormat):
    """
    https://doc.qt.io/qt-6/qtextimageformat.html

    **Detailed Description**

    Inline images are represented by a Unicode value U+FFFC (OBJECT REPLACEMENT
    CHARACTER) which has an associated QTextImageFormat. The image format
    specifies a name with **setName** () that is used to locate the image. The
    size of the rectangle that the image will occupy is specified in pixels
    using **setWidth** () and **setHeight** (). The desired image quality may be
    set with **setQuality** ().

    Images can be supplied in any format for which Qt has an image reader, so
    SVG drawings can be included alongside PNG, TIFF and other bitmap formats.

    **See also** **QImage**  and **QImageReader** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextimageformat.html#QTextImageFormat

        **QTextImageFormat::QTextImageFormat()**

        Creates a new image format object.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QTextImageFormat") -> None:
        """
        https://doc.qt.io/qt-6/qtextimageformat.html#QTextImageFormat

        **QTextImageFormat::QTextImageFormat()**

        Creates a new image format object.
        """
        ...

    def setQuality(self, quality: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtextimageformat.html#setQuality

        **[since 5.12] void QTextImageFormat::setQuality(int quality = 100)**

        Sets the quality that should be used by exporters when exporting the
        image. **QTextDocumentWriter**  will export jpg images with the
        **quality** set here when exporting to ODF files if **quality** is set
        to a value between 0 and 100. Or it will export png images if
        **quality** is set to 100 (default) or greater.

        This function was introduced in Qt 5.12.

        **See also** **quality** ().
        """
        ...

    def setHeight(self, aheight: float) -> None:
        """
        https://doc.qt.io/qt-6/qtextimageformat.html#setHeight

        **void QTextImageFormat::setHeight(qreal height )**

        Sets the **height** of the rectangle occupied by the image.

        **See also** **height** () and **setWidth** ().
        """
        ...

    def setWidth(self, awidth: float) -> None:
        """
        https://doc.qt.io/qt-6/qtextimageformat.html#setWidth

        **void QTextImageFormat::setWidth(qreal width )**

        Sets the **width** of the rectangle occupied by the image.

        **See also** **width** () and **setHeight** ().
        """
        ...

    def setName(self, aname: str) -> None:
        """
        https://doc.qt.io/qt-6/qtextimageformat.html#setName

        **void QTextImageFormat::setName(const QString & name )**

        Sets the **name** of the image. The **name** is used to locate the image
        in the application's resources.

        **See also** **name** ().
        """
        ...

    def quality(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextimageformat.html#quality

        **[since 5.12] int QTextImageFormat::quality() const**

        Returns the value set by **setQuality** ().

        This function was introduced in Qt 5.12.

        **See also** **setQuality** ().
        """
        ...

    def height(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextimageformat.html#height

        **qreal QTextImageFormat::height() const**

        Returns the height of the rectangle occupied by the image.

        **See also** **width** () and **setHeight** ().
        """
        ...

    def width(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextimageformat.html#width

        **qreal QTextImageFormat::width() const**

        Returns the width of the rectangle occupied by the image.

        **See also** **height** () and **setWidth** ().
        """
        ...

    def name(self) -> str:
        """
        https://doc.qt.io/qt-6/qtextimageformat.html#name

        **QString QTextImageFormat::name() const**

        Returns the name of the image. The name refers to an entry in the
        application's resources file.

        **See also** **setName** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextimageformat.html#isValid

        **bool QTextImageFormat::isValid() const**

        Returns `true` if this image format is valid; otherwise returns `false`.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QLinearGradient(QGradient):
    """
    https://doc.qt.io/qt-6/qlineargradient.html

    **Detailed Description**

    Linear gradients interpolate colors between start and end points. Outside
    these points the gradient is either padded, reflected or repeated depending
    on the currently set **spread**  method:

    ![](images/qlineargradient-pad.png)![](images/qlineargradient-
    reflect.png)![](images/qlineargradient-repeat.png)
    **PadSpread**
    (default)**ReflectSpread** **RepeatSpread**

    The colors in a gradient is defined using stop points of the
    **QGradientStop**  type, i.e. a position and a color. Use the
    **QGradient::setColorAt** () or the **QGradient::setStops** () function to
    define the stop points. It is the gradient's complete set of stop points
    that describes how the gradient area should be filled. If no stop points
    have been specified, a gradient of black at 0 to white at 1 is used.

    In addition to the functions inherited from **QGradient** , the
    QLinearGradient class provides the **finalStop** () function which returns
    the final stop point of the gradient, and the **start** () function
    returning the start point of the gradient.

    **See also** **QRadialGradient** , **QConicalGradient** , and **The
    Gradients Example** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qlineargradient.html#QLinearGradient

        **QLinearGradient::QLinearGradient()**

        Constructs a default linear gradient with interpolation area between (0,
        0) and (1, 1).

        **See also** **QGradient::setColorAt** (), **setStart** (), and
        **setFinalStop** ().
        """
        ...

    @typing.overload
    def __init__(self, start: QtCore.QPointF, finalStop: QtCore.QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qlineargradient.html#QLinearGradient-1

        **QLinearGradient::QLinearGradient(const QPointF & start , const QPointF
        & finalStop )**

        Constructs a linear gradient with interpolation area between the given
        **start** point and **finalStop**.

        **Note:** The expected parameter values are in pixels.

        **See also** **QGradient::setColorAt** () and **QGradient::setStops**
        ().
        """
        ...

    @typing.overload
    def __init__(
        self, xStart: float, yStart: float, xFinalStop: float, yFinalStop: float
    ) -> None:
        """
        https://doc.qt.io/qt-6/qlineargradient.html#QLinearGradient-2

        **QLinearGradient::QLinearGradient(qreal x1 , qreal y1 , qreal x2 ,
        qreal y2 )**

        Constructs a linear gradient with interpolation area between ( **x1** ,
        **y1** ) and ( **x2** , **y2** ).

        **Note:** The expected parameter values are in pixels.

        **See also** **QGradient::setColorAt** () and **QGradient::setStops**
        ().
        """
        ...

    @typing.overload
    def __init__(self, a0: "QLinearGradient") -> None:
        """
        https://doc.qt.io/qt-6/qlineargradient.html#QLinearGradient

        **QLinearGradient::QLinearGradient()**

        Constructs a default linear gradient with interpolation area between (0,
        0) and (1, 1).

        **See also** **QGradient::setColorAt** (), **setStart** (), and
        **setFinalStop** ().
        """
        ...

    @typing.overload
    def setFinalStop(self, stop: QtCore.QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qlineargradient.html#setFinalStop

        **void QLinearGradient::setFinalStop(const QPointF & stop )**

        Sets the final stop point of this linear gradient in logical coordinates
        to **stop**.

        **See also** **finalStop** ().
        """
        ...

    @typing.overload
    def setFinalStop(self, x: float, y: float) -> None:
        """
        https://doc.qt.io/qt-6/qlineargradient.html#setFinalStop-1

        **void QLinearGradient::setFinalStop(qreal x , qreal y )**

        This is an overloaded function.

        Sets the final stop point of this linear gradient in logical coordinates
        to **x** , **y**.

        **See also** **start** ().
        """
        ...

    @typing.overload
    def setStart(self, start: QtCore.QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qlineargradient.html#setStart

        **void QLinearGradient::setStart(const QPointF & start )**

        Sets the start point of this linear gradient in logical coordinates to
        **start**.

        **See also** **start** ().
        """
        ...

    @typing.overload
    def setStart(self, x: float, y: float) -> None:
        """
        https://doc.qt.io/qt-6/qlineargradient.html#setStart-1

        **void QLinearGradient::setStart(qreal x , qreal y )**

        This is an overloaded function.

        Sets the start point of this linear gradient in logical coordinates to
        **x** , **y**.

        **See also** **start** ().
        """
        ...

    def finalStop(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qlineargradient.html#finalStop

        **QPointF QLinearGradient::finalStop() const**

        Returns the final stop point of this linear gradient in logical
        coordinates.

        **See also** **setFinalStop** () and **QGradient::stops** ().
        """
        ...

    def start(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qlineargradient.html#start

        **QPointF QLinearGradient::start() const**

        Returns the start point of this linear gradient in logical coordinates.

        **See also** **setStart** () and **QGradient::stops** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QQmlScriptString(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qqmlscriptstring.html

    **Detailed Description**

    QQmlScriptString is used to create **QObject**  properties that accept a
    script "assignment" from QML.

    Normally, the following QML would result in a binding being established for
    the `script` property; i.e. `script` would be assigned the value obtained
    from running `myObj.value = Math.max(myValue, 100)`

    MyType {
            script: myObj.value = Math.max(myValue, 100)
        }

    If instead the property had a type of QQmlScriptString, the script itself --
    **myObj.value = Math.max(myValue, 100)** \\-- would be passed to the `script`
    property and the class could choose how to handle it. Typically, the class
    will evaluate the script at some later time using a **QQmlExpression** .

    **QQmlExpression**  expr(scriptString);
        expr.evaluate();

    **See also** **QQmlExpression** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qqmlscriptstring.html#QQmlScriptString

        **QQmlScriptString::QQmlScriptString()**

        Constructs an empty instance.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QQmlScriptString") -> None:
        """
        https://doc.qt.io/qt-6/qqmlscriptstring.html#QQmlScriptString-1

        **QQmlScriptString::QQmlScriptString(const QQmlScriptString & other )**

        Copies **other**.
        """
        ...

    def booleanLiteral(self) -> typing.Tuple[bool, bool]:
        """
        https://doc.qt.io/qt-6/qqmlscriptstring.html#booleanLiteral

        **bool QQmlScriptString::booleanLiteral(bool * ok ) const**

        If the content of the **QQmlScriptString**  is a boolean literal,
        returns the boolean value and sets **ok** to true. Otherwise returns
        false and sets **ok** to false.
        """
        ...

    def numberLiteral(self) -> typing.Tuple[float, bool]:
        """
        https://doc.qt.io/qt-6/qqmlscriptstring.html#numberLiteral

        **qreal QQmlScriptString::numberLiteral(bool * ok ) const**

        If the content of the **QQmlScriptString**  is a number literal, returns
        that number and sets **ok** to true. Otherwise returns 0.0 and sets
        **ok** to false.
        """
        ...

    def stringLiteral(self) -> str:
        """
        https://doc.qt.io/qt-6/qqmlscriptstring.html#stringLiteral

        **QString QQmlScriptString::stringLiteral() const**

        If the content of the **QQmlScriptString**  is a string literal, returns
        that string. Otherwise returns a null **QString** .
        """
        ...

    def isNullLiteral(self) -> bool:
        """
        https://doc.qt.io/qt-6/qqmlscriptstring.html#isNullLiteral

        **bool QQmlScriptString::isNullLiteral() const**

        Returns whether the content of the **QQmlScriptString**  is the `null`
        literal.
        """
        ...

    def isUndefinedLiteral(self) -> bool:
        """
        https://doc.qt.io/qt-6/qqmlscriptstring.html#isUndefinedLiteral

        **bool QQmlScriptString::isUndefinedLiteral() const**

        Returns whether the content of the **QQmlScriptString**  is the
        `undefined` literal.
        """
        ...

    def isEmpty(self) -> bool:
        """
        https://doc.qt.io/qt-6/qqmlscriptstring.html#isEmpty

        **bool QQmlScriptString::isEmpty() const**

        Returns whether the **QQmlScriptString**  is empty.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtNetwork import *
import enum


class QNetworkAccessManager(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qnetworkaccessmanager.html

    **Detailed Description**

    The Network Access API is constructed around one QNetworkAccessManager
    object, which holds the common configuration and settings for the requests
    it sends. It contains the proxy and cache configuration, as well as the
    signals related to such issues, and reply signals that can be used to
    monitor the progress of a network operation. One QNetworkAccessManager
    instance should be enough for the whole Qt application. Since
    QNetworkAccessManager is based on **QObject** , it can only be used from the
    thread it belongs to.

    Once a QNetworkAccessManager object has been created, the application can
    use it to send requests over the network. A group of standard functions are
    supplied that take a request and optional data, and each return a
    **QNetworkReply**  object. The returned object is used to obtain any data
    returned in response to the corresponding request.

    A simple download off the network could be accomplished with:

    **QNetworkAccessManager**  *manager = new **QNetworkAccessManager** (this);
    connect(manager, &**QNetworkAccessManager** ::finished,
                this,
    &MyClass::replyFinished);

        manager->get(**QNetworkRequest**
    (**QUrl** ("http://qt-project.org")));

    QNetworkAccessManager has an asynchronous API. When the `replyFinished` slot
    above is called, the parameter it takes is the **QNetworkReply**  object
    containing the downloaded data as well as meta-data (headers, etc.).

    **Note:** After the request has finished, it is the responsibility of the
    user to delete the **QNetworkReply**  object at an appropriate time. Do not
    directly delete it inside the slot connected to **finished** (). You can use
    the **deleteLater** () function.

    **Note:** QNetworkAccessManager queues the requests it receives. The number
    of requests executed in parallel is dependent on the protocol. Currently,
    for the HTTP protocol on desktop platforms, 6 requests are executed in
    parallel for one host/port combination.

    A more involved example, assuming the manager is already existent, can be:

    **QNetworkRequest**  request;
        request.setUrl(**QUrl** ("http://qt-
    project.org"));
        request.setRawHeader("User-Agent", "MyOwnBrowser 1.0");
    **QNetworkReply**  *reply = manager->get(request);
        connect(reply,
    &**QIODevice** ::readyRead, this, &MyClass::slotReadyRead);
    connect(reply, &**QNetworkReply** ::errorOccurred,
                this,
    &MyClass::slotError);
        connect(reply, &**QNetworkReply** ::sslErrors,
    this, &MyClass::slotSslErrors);

    **See also** **QNetworkRequest** , **QNetworkReply** , and **QNetworkProxy**
    .
    """

    class Operation(enum.Enum):
        HeadOperation: QNetworkAccessManager = ...
        GetOperation: QNetworkAccessManager = ...
        PutOperation: QNetworkAccessManager = ...
        PostOperation: QNetworkAccessManager = ...
        DeleteOperation: QNetworkAccessManager = ...
        CustomOperation: QNetworkAccessManager = ...

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#QNetworkAccessManager

        **QNetworkAccessManager::QNetworkAccessManager(QObject * parent =
        nullptr)**

        Constructs a QNetworkAccessManager object that is the center of the
        Network Access API and sets **parent** as the parent object.
        """
        ...

    def setTransferTimeout(self, timeout: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#setTransferTimeout

        **[since 5.15] void QNetworkAccessManager::setTransferTimeout(int
        timeout = QNetworkRequest::DefaultTransferTimeoutConstant)**

        Sets **timeout** as the transfer timeout in milliseconds.

        Transfers are aborted if no bytes are transferred before the timeout
        expires. Zero means no timer is set. If no argument is provided, the
        timeout is **QNetworkRequest::DefaultTransferTimeoutConstant** . If this
        function is not called, the timeout is disabled and has the value zero.
        The request-specific non-zero timeouts set for the requests that are
        executed override this value. This means that if
        **QNetworkAccessManager**  has an enabled timeout, it needs to be
        disabled to execute a request without a timeout.

        This function was introduced in Qt 5.15.

        **See also** **transferTimeout** ().
        """
        ...

    def transferTimeout(self) -> int:
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#transferTimeout

        **[since 5.15] int QNetworkAccessManager::transferTimeout() const**

        Returns the timeout used for transfers, in milliseconds.

        This timeout is zero if **setTransferTimeout** () hasn't been called,
        which means that the timeout is not used.

        This function was introduced in Qt 5.15.

        **See also** **setTransferTimeout** ().
        """
        ...

    def setAutoDeleteReplies(self, autoDelete: bool) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#setAutoDeleteReplies

        **[since 5.14] void QNetworkAccessManager::setAutoDeleteReplies(bool
        shouldAutoDelete )**

        Enables or disables automatic deletion of **QNetworkReplies** .

        Setting **shouldAutoDelete** to true is the same as setting the
        **QNetworkRequest::AutoDeleteReplyOnFinishAttribute**  attribute to true
        on all **future** **QNetworkRequests**  passed to this instance of
        **QNetworkAccessManager**  unless the attribute was already explicitly
        set on the **QNetworkRequest** .

        This function was introduced in Qt 5.14.

        **See also** **autoDeleteReplies**  and
        **QNetworkRequest::AutoDeleteReplyOnFinishAttribute** .
        """
        ...

    def autoDeleteReplies(self) -> bool:
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#autoDeleteReplies

        **[since 5.14] bool QNetworkAccessManager::autoDeleteReplies() const**

        Returns the true if **QNetworkAccessManager**  is currently configured
        to automatically delete QNetworkReplies, false otherwise.

        This function was introduced in Qt 5.14.

        **See also** **setAutoDeleteReplies**  and
        **QNetworkRequest::AutoDeleteReplyOnFinishAttribute** .
        """
        ...

    def isStrictTransportSecurityStoreEnabled(self) -> bool:
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#isStrictTransportSecur
        ityStoreEnabled

        **[since 5.10] bool
        QNetworkAccessManager::isStrictTransportSecurityStoreEnabled() const**

        Returns true if HSTS cache uses a permanent store to load and store HSTS
        policies.

        This function was introduced in Qt 5.10.

        **See also** **enableStrictTransportSecurityStore** ().
        """
        ...

    def enableStrictTransportSecurityStore(
        self, enabled: bool, storeDir: str = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#enableStrictTransportS
        ecurityStore

        **[since 5.10] void
        QNetworkAccessManager::enableStrictTransportSecurityStore(bool enabled ,
        const QString & storeDir = QString())**

        If **enabled** is `true`, the internal HSTS cache will use a persistent
        store to read and write HSTS policies. **storeDir** defines where this
        store will be located. The default location is defined by
        **QStandardPaths::CacheLocation** . If there is no writable
        QStandartPaths::CacheLocation and **storeDir** is an empty string, the
        store will be located in the program's working directory.

        **Note:** If HSTS cache already contains HSTS policies by the time
        persistent store is enabled, these policies will be preserved in the
        store. In case both cache and store contain the same known hosts,
        policies from cache are considered to be more up-to-date (and thus will
        overwrite the previous values in the store). If this behavior is
        undesired, enable HSTS store before enabling Strict Transport Security.
        By default, the persistent store of HSTS policies is disabled.

        This function was introduced in Qt 5.10.

        **See also** **isStrictTransportSecurityStoreEnabled** (),
        **setStrictTransportSecurityEnabled** (), and
        **QStandardPaths::standardLocations** ().
        """
        ...

    def redirectPolicy(self) -> "QNetworkRequest.RedirectPolicy":
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#redirectPolicy

        **[since 5.9] QNetworkRequest::RedirectPolicy
        QNetworkAccessManager::redirectPolicy() const**

        Returns the redirect policy that is used when creating new requests.

        This function was introduced in Qt 5.9.

        **See also** **setRedirectPolicy** () and
        **QNetworkRequest::RedirectPolicy** .
        """
        ...

    def setRedirectPolicy(self, policy: "QNetworkRequest.RedirectPolicy") -> None:
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#setRedirectPolicy

        **[since 5.9] void
        QNetworkAccessManager::setRedirectPolicy(QNetworkRequest::RedirectPolicy
        policy )**

        Sets the manager's redirect policy to be the **policy** specified. This
        policy will affect all subsequent requests created by the manager.

        Use this function to enable or disable HTTP redirects on the manager's
        level.

        **Note:** When creating a request
        QNetworkRequest::RedirectAttributePolicy has the highest priority, next
        by priority the manager's policy.

        The default value is **QNetworkRequest::NoLessSafeRedirectPolicy** .
        Clients relying on manual redirect handling are encouraged to set this
        policy explicitly in their code.

        This function was introduced in Qt 5.9.

        **See also** **redirectPolicy** () and
        **QNetworkRequest::RedirectPolicy** .
        """
        ...

    def strictTransportSecurityHosts(self) -> typing.List[QHstsPolicy]:
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#strictTransportSecurit
        yHosts

        **[since 5.9] QList<QHstsPolicy>
        QNetworkAccessManager::strictTransportSecurityHosts() const**

        Returns the list of HTTP Strict Transport Security policies. This list
        can differ from what was initially set via
        **addStrictTransportSecurityHosts** () if HSTS cache was updated from a
        "Strict-Transport-Security" response header.

        This function was introduced in Qt 5.9.

        **See also** **addStrictTransportSecurityHosts** () and **QHstsPolicy**
        .
        """
        ...

    def addStrictTransportSecurityHosts(
        self, knownHosts: typing.Iterable[QHstsPolicy]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#addStrictTransportSecu
        rityHosts

        **[since 5.9] void
        QNetworkAccessManager::addStrictTransportSecurityHosts(const
        QList<QHstsPolicy> & knownHosts )**

        Adds HTTP Strict Transport Security policies into HSTS cache.
        **knownHosts** contains the known hosts that have **QHstsPolicy**
        information.

        **Note:** An expired policy will remove a known host from the cache, if
        previously present.

        **Note:** While processing HTTP responses, **QNetworkAccessManager**
        can also update the HSTS cache, removing or updating exitsting policies
        or introducing new **knownHosts**. The current implementation thus is
        server-driven, client code can provide **QNetworkAccessManager**  with
        previously known or discovered policies, but this information can be
        overridden by "Strict-Transport-Security" response headers.

        This function was introduced in Qt 5.9.

        **See also**  addStrictTransportSecurityHosts(),
        **enableStrictTransportSecurityStore** (), and **QHstsPolicy** .
        """
        ...

    def isStrictTransportSecurityEnabled(self) -> bool:
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#isStrictTransportSecur
        ityEnabled

        **[since 5.9] bool
        QNetworkAccessManager::isStrictTransportSecurityEnabled() const**

        Returns true if HTTP Strict Transport Security (HSTS) was enabled. By
        default HSTS is disabled.

        This function was introduced in Qt 5.9.

        **See also** **setStrictTransportSecurityEnabled** ().
        """
        ...

    def setStrictTransportSecurityEnabled(self, enabled: bool) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#setStrictTransportSecu
        rityEnabled

        **[since 5.9] void
        QNetworkAccessManager::setStrictTransportSecurityEnabled(bool enabled
        )**

        If **enabled** is `true`, **QNetworkAccessManager**  follows the HTTP
        Strict Transport Security policy (HSTS, RFC6797). When processing a
        request, **QNetworkAccessManager**  automatically replaces the "http"
        scheme with "https" and uses a secure transport for HSTS hosts. If it's
        set explicitly, port 80 is replaced by port 443.

        When HSTS is enabled, for each HTTP response containing HSTS header and
        received over a secure transport, **QNetworkAccessManager**  will update
        its HSTS cache, either remembering a host with a valid policy or
        removing a host with an expired or disabled HSTS policy.

        This function was introduced in Qt 5.9.

        **See also** **isStrictTransportSecurityEnabled** ().
        """
        ...

    def clearConnectionCache(self) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#clearConnectionCache

        **[since 5.9] void QNetworkAccessManager::clearConnectionCache()**

        Flushes the internal cache of network connections. In contrast to
        **clearAccessCache** () the authentication data is preserved.

        This function was introduced in Qt 5.9.

        **See also** **clearAccessCache** ().
        """
        ...

    def supportedSchemesImplementation(self) -> typing.List[str]:
        ...

    def connectToHost(self, hostName: str, port: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#connectToHost

        **[since 5.2] void QNetworkAccessManager::connectToHost(const QString &
        hostName , quint16 port = 80)**

        Initiates a connection to the host given by **hostName** at port
        **port**. This function is useful to complete the TCP handshake to a
        host before the HTTP request is made, resulting in a lower network
        latency.

        **Note:** This function has no possibility to report errors.

        This function was introduced in Qt 5.2.

        **See also** **connectToHostEncrypted** (), **get** (), **post** (),
        **put** (), and **deleteResource** ().
        """
        ...

    @typing.overload
    def connectToHostEncrypted(
        self,
        hostName: str,
        port: int = ...,
        sslConfiguration: "QSslConfiguration" = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#connectToHostEncrypted

        **[since 5.2] void QNetworkAccessManager::connectToHostEncrypted(const
        QString & hostName , quint16 port = 443, const QSslConfiguration &
        sslConfiguration = QSslConfiguration::defaultConfiguration())**

        Initiates a connection to the host given by **hostName** at port
        **port** , using **sslConfiguration**. This function is useful to
        complete the TCP and SSL handshake to a host before the HTTPS request is
        made, resulting in a lower network latency.

        **Note:** Preconnecting a HTTP/2 connection can be done by calling
        setAllowedNextProtocols() on **sslConfiguration** with
        QSslConfiguration::ALPNProtocolHTTP2 contained in the list of allowed
        protocols. When using HTTP/2, one single connection per host is enough,
        i.e. calling this method multiple times per host will not result in
        faster network transactions.

        **Note:** This function has no possibility to report errors.

        This function was introduced in Qt 5.2.

        **See also** **connectToHost** (), **get** (), **post** (), **put** (),
        and **deleteResource** ().
        """
        ...

    @typing.overload
    def connectToHostEncrypted(
        self,
        hostName: str,
        port: int,
        sslConfiguration: "QSslConfiguration",
        peerName: str,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#connectToHostEncrypted
        -1

        **[since 5.13] void QNetworkAccessManager::connectToHostEncrypted(const
        QString & hostName , quint16 port , const QSslConfiguration &
        sslConfiguration , const QString & peerName )**

        This is an overloaded function.

        Initiates a connection to the host given by **hostName** at port
        **port** , using **sslConfiguration** with **peerName** set to be the
        hostName used for certificate validation. This function is useful to
        complete the TCP and SSL handshake to a host before the HTTPS request is
        made, resulting in a lower network latency.

        **Note:** Preconnecting a HTTP/2 connection can be done by calling
        setAllowedNextProtocols() on **sslConfiguration** with
        QSslConfiguration::ALPNProtocolHTTP2 contained in the list of allowed
        protocols. When using HTTP/2, one single connection per host is enough,
        i.e. calling this method multiple times per host will not result in
        faster network transactions.

        **Note:** This function has no possibility to report errors.

        This function was introduced in Qt 5.13.

        **See also** **connectToHost** (), **get** (), **post** (), **put** (),
        and **deleteResource** ().
        """
        ...

    def supportedSchemes(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#supportedSchemes

        **[virtual, since 5.2] QStringList
        QNetworkAccessManager::supportedSchemes() const**

        Lists all the URL schemes supported by the access manager.

        Reimplement this method to provide your own supported schemes in a
        **QNetworkAccessManager**  subclass. It is for instance necessary when
        your subclass provides support for new protocols.

        This function was introduced in Qt 5.2.
        """
        ...

    def clearAccessCache(self) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#clearAccessCache

        **[since 5.0] void QNetworkAccessManager::clearAccessCache()**

        Flushes the internal cache of authentication data and network
        connections.

        This function is useful for doing auto tests.

        This function was introduced in Qt 5.0.

        **See also** **clearConnectionCache** ().
        """
        ...

    @typing.overload
    def sendCustomRequest(
        self,
        request: "QNetworkRequest",
        verb: QtCore.QByteArray,
        data: typing.Optional[QtCore.QIODevice] = ...,
    ) -> "QNetworkReply":
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#sendCustomRequest

        **QNetworkReply *QNetworkAccessManager::sendCustomRequest(const
        QNetworkRequest & request , const QByteArray & verb , QIODevice * data =
        nullptr)**

        Sends a custom request to the server identified by the URL of
        **request**.

        It is the user's responsibility to send a **verb** to the server that is
        valid according to the HTTP specification.

        This method provides means to send verbs other than the common ones
        provided via **get** () or **post** () etc., for instance sending an
        HTTP OPTIONS command.

        If **data** is not empty, the contents of the **data** device will be
        uploaded to the server; in that case, data must be open for reading and
        must remain valid until the **finished** () signal is emitted for this
        reply.

        **Note:** This feature is currently available for HTTP(S) only.

        **See also** **get** (), **post** (), **put** (), and **deleteResource**
        ().
        """
        ...

    @typing.overload
    def sendCustomRequest(
        self,
        request: "QNetworkRequest",
        verb: QtCore.QByteArray,
        data: QtCore.QByteArray,
    ) -> "QNetworkReply":
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#sendCustomRequest-1

        **[since 5.8] QNetworkReply
        *QNetworkAccessManager::sendCustomRequest(const QNetworkRequest &
        request , const QByteArray & verb , const QByteArray & data )**

        This is an overloaded function.

        Sends the contents of the **data** byte array to the destination
        specified by **request**.

        This function was introduced in Qt 5.8.
        """
        ...

    @typing.overload
    def sendCustomRequest(
        self,
        request: "QNetworkRequest",
        verb: QtCore.QByteArray,
        multiPart: QHttpMultiPart,
    ) -> "QNetworkReply":
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#sendCustomRequest-2

        **[since 5.8] QNetworkReply
        *QNetworkAccessManager::sendCustomRequest(const QNetworkRequest &
        request , const QByteArray & verb , QHttpMultiPart * multiPart )**

        This is an overloaded function.

        Sends a custom request to the server identified by the URL of
        **request**.

        Sends the contents of the **multiPart** message to the destination
        specified by **request**.

        This can be used for sending MIME multipart messages for custom verbs.

        This function was introduced in Qt 5.8.

        **See also** **QHttpMultiPart** , **QHttpPart** , and **put** ().
        """
        ...

    def deleteResource(self, request: "QNetworkRequest") -> "QNetworkReply":
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#deleteResource

        **QNetworkReply *QNetworkAccessManager::deleteResource(const
        QNetworkRequest & request )**

        Sends a request to delete the resource identified by the URL of
        **request**.

        **Note:** This feature is currently available for HTTP only, performing
        an HTTP DELETE request.

        **See also** **get** (), **post** (), **put** (), and
        **sendCustomRequest** ().
        """
        ...

    def setCache(self, cache: QAbstractNetworkCache) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#setCache

        **void QNetworkAccessManager::setCache(QAbstractNetworkCache * cache )**

        Sets the manager's network cache to be the **cache** specified. The
        cache is used for all requests dispatched by the manager.

        Use this function to set the network cache object to a class that
        implements additional features, like saving the cookies to permanent
        storage.

        **Note:****QNetworkAccessManager**  takes ownership of the **cache**
        object.

        **QNetworkAccessManager**  by default does not have a set cache. Qt
        provides a simple disk cache, **QNetworkDiskCache** , which can be used.

        **See also** **cache** () and **QNetworkRequest::CacheLoadControl** .
        """
        ...

    def cache(self) -> QAbstractNetworkCache:
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#cache

        **QAbstractNetworkCache *QNetworkAccessManager::cache() const**

        Returns the cache that is used to store data obtained from the network.

        **See also** **setCache** ().
        """
        ...

    def setProxyFactory(self, factory: "QNetworkProxyFactory") -> None:
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#setProxyFactory

        **void QNetworkAccessManager::setProxyFactory(QNetworkProxyFactory *
        factory )**

        Sets the proxy factory for this class to be **factory**. A proxy factory
        is used to determine a more specific list of proxies to be used for a
        given request, instead of trying to use the same proxy value for all
        requests.

        All queries sent by **QNetworkAccessManager**  will have type
        **QNetworkProxyQuery::UrlRequest** .

        For example, a proxy factory could apply the following rules:

        * if the target address is in the local network (for example, if the
        hostname contains no dots or if it's an IP address in the organization's
        range), return **QNetworkProxy::NoProxy**
          * if the request is FTP,
        return an FTP proxy
          * if the request is HTTP or HTTPS, then return an
        HTTP proxy
          * otherwise, return a SOCKSv5 proxy server

        The lifetime of the object **factory** will be managed by
        **QNetworkAccessManager** . It will delete the object when necessary.

        **Note:** If a specific proxy is set with **setProxy** (), the factory
        will not be used.

        **See also** **proxyFactory** (), **setProxy** (), and
        **QNetworkProxyQuery** .
        """
        ...

    def proxyFactory(self) -> "QNetworkProxyFactory":
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#proxyFactory

        **QNetworkProxyFactory *QNetworkAccessManager::proxyFactory() const**

        Returns the proxy factory that this **QNetworkAccessManager**  object is
        using to determine the proxies to be used for requests.

        Note that the pointer returned by this function is managed by
        **QNetworkAccessManager**  and could be deleted at any time.

        **See also** **setProxyFactory** () and **proxy** ().
        """
        ...

    def createRequest(
        self,
        op: "QNetworkAccessManager.Operation",
        request: "QNetworkRequest",
        device: typing.Optional[QtCore.QIODevice] = ...,
    ) -> "QNetworkReply":
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#createRequest

        **[virtual protected] QNetworkReply
        *QNetworkAccessManager::createRequest(QNetworkAccessManager::Operation
        op , const QNetworkRequest & originalReq , QIODevice * outgoingData =
        nullptr)**

        Returns a new **QNetworkReply**  object to handle the operation **op**
        and request **originalReq**. The device **outgoingData** is always 0 for
        Get and Head requests, but is the value passed to **post** () and
        **put** () in those operations (the **QByteArray**  variants will pass a
        **QBuffer**  object).

        The default implementation calls **QNetworkCookieJar::cookiesForUrl** ()
        on the cookie jar set with **setCookieJar** () to obtain the cookies to
        be sent to the remote server.

        The returned object must be in an open state.
        """
        ...

    @typing.overload
    def put(
        self, request: "QNetworkRequest", data: QtCore.QIODevice
    ) -> "QNetworkReply":
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#put

        **QNetworkReply *QNetworkAccessManager::put(const QNetworkRequest &
        request , QIODevice * data )**

        Uploads the contents of **data** to the destination **request** and
        returns a new **QNetworkReply**  object that will be open for reply.

        **data** must be opened for reading when this function is called and
        must remain valid until the **finished** () signal is emitted for this
        reply.

        Whether anything will be available for reading from the returned object
        is protocol dependent. For HTTP, the server may send a small HTML page
        indicating the upload was successful (or not). Other protocols will
        probably have content in their replies.

        **Note:** For HTTP, this request will send a PUT request, which most
        servers do not allow. Form upload mechanisms, including that of
        uploading files through HTML forms, use the POST mechanism.

        **See also** **get** (), **post** (), **deleteResource** (), and
        **sendCustomRequest** ().
        """
        ...

    @typing.overload
    def put(
        self, request: "QNetworkRequest", data: QtCore.QByteArray
    ) -> "QNetworkReply":
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#put-1

        **QNetworkReply *QNetworkAccessManager::put(const QNetworkRequest &
        request , const QByteArray & data )**

        This is an overloaded function.

        Sends the contents of the **data** byte array to the destination
        specified by **request**.
        """
        ...

    @typing.overload
    def put(
        self, request: "QNetworkRequest", multiPart: QHttpMultiPart
    ) -> "QNetworkReply":
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#put-2

        **QNetworkReply *QNetworkAccessManager::put(const QNetworkRequest &
        request , QHttpMultiPart * multiPart )**

        This is an overloaded function.

        Sends the contents of the **multiPart** message to the destination
        specified by **request**.

        This can be used for sending MIME multipart messages over HTTP.

        **See also** **QHttpMultiPart** , **QHttpPart** , and **post** ().
        """
        ...

    @typing.overload
    def post(
        self, request: "QNetworkRequest", data: QtCore.QIODevice
    ) -> "QNetworkReply":
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#post

        **QNetworkReply *QNetworkAccessManager::post(const QNetworkRequest &
        request , QIODevice * data )**

        Sends an HTTP POST request to the destination specified by **request**
        and returns a new **QNetworkReply**  object opened for reading that will
        contain the reply sent by the server. The contents of the **data**
        device will be uploaded to the server.

        **data** must be open for reading and must remain valid until the
        **finished** () signal is emitted for this reply.

        **Note:** Sending a POST request on protocols other than HTTP and HTTPS
        is undefined and will probably fail.

        **See also** **get** (), **put** (), **deleteResource** (), and
        **sendCustomRequest** ().
        """
        ...

    @typing.overload
    def post(
        self, request: "QNetworkRequest", data: QtCore.QByteArray
    ) -> "QNetworkReply":
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#post-1

        **QNetworkReply *QNetworkAccessManager::post(const QNetworkRequest &
        request , const QByteArray & data )**

        This is an overloaded function.

        Sends the contents of the **data** byte array to the destination
        specified by **request**.
        """
        ...

    @typing.overload
    def post(
        self, request: "QNetworkRequest", multiPart: QHttpMultiPart
    ) -> "QNetworkReply":
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#post-2

        **QNetworkReply *QNetworkAccessManager::post(const QNetworkRequest &
        request , QHttpMultiPart * multiPart )**

        This is an overloaded function.

        Sends the contents of the **multiPart** message to the destination
        specified by **request**.

        This can be used for sending MIME multipart messages over HTTP.

        **See also** **QHttpMultiPart** , **QHttpPart** , and **put** ().
        """
        ...

    def get(self, request: "QNetworkRequest") -> "QNetworkReply":
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#get

        **QNetworkReply *QNetworkAccessManager::get(const QNetworkRequest &
        request )**

        Posts a request to obtain the contents of the target **request** and
        returns a new **QNetworkReply**  object opened for reading which emits
        the **readyRead** () signal whenever new data arrives.

        The contents as well as associated headers will be downloaded.

        **See also** **post** (), **put** (), **deleteResource** (), and
        **sendCustomRequest** ().
        """
        ...

    def head(self, request: "QNetworkRequest") -> "QNetworkReply":
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#head

        **QNetworkReply *QNetworkAccessManager::head(const QNetworkRequest &
        request )**

        Posts a request to obtain the network headers for **request** and
        returns a new **QNetworkReply**  object which will contain such headers.

        The function is named after the HTTP request associated (HEAD).
        """
        ...

    def setCookieJar(self, cookieJar: "QNetworkCookieJar") -> None:
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#setCookieJar

        **void QNetworkAccessManager::setCookieJar(QNetworkCookieJar * cookieJar
        )**

        Sets the manager's cookie jar to be the **cookieJar** specified. The
        cookie jar is used by all requests dispatched by the manager.

        Use this function to set the cookie jar object to a class that
        implements additional features, like saving the cookies to permanent
        storage.

        **Note:****QNetworkAccessManager**  takes ownership of the **cookieJar**
        object.

        If **cookieJar** is in the same thread as this **QNetworkAccessManager**
        , it will set the parent of the **cookieJar** so that the cookie jar is
        deleted when this object is deleted as well. If you want to share cookie
        jars between different **QNetworkAccessManager**  objects, you may want
        to set the cookie jar's parent to 0 after calling this function.

        **QNetworkAccessManager**  by default does not implement any cookie
        policy of its own: it accepts all cookies sent by the server, as long as
        they are well formed and meet the minimum security requirements (cookie
        domain matches the request's and cookie path matches the request's). In
        order to implement your own security policy, override the
        **QNetworkCookieJar::cookiesForUrl** () and
        **QNetworkCookieJar::setCookiesFromUrl** () virtual functions. Those
        functions are called by **QNetworkAccessManager**  when it detects a new
        cookie.

        **See also** **cookieJar** (), **QNetworkCookieJar::cookiesForUrl** (),
        and **QNetworkCookieJar::setCookiesFromUrl** ().
        """
        ...

    def cookieJar(self) -> "QNetworkCookieJar":
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#cookieJar

        **QNetworkCookieJar *QNetworkAccessManager::cookieJar() const**

        Returns the **QNetworkCookieJar**  that is used to store cookies
        obtained from the network as well as cookies that are about to be sent.

        **See also** **setCookieJar** ().
        """
        ...

    def setProxy(self, proxy: "QNetworkProxy") -> None:
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#setProxy

        **void QNetworkAccessManager::setProxy(const QNetworkProxy & proxy )**

        Sets the proxy to be used in future requests to be **proxy**. This does
        not affect requests that have already been sent. The
        **proxyAuthenticationRequired** () signal will be emitted if the proxy
        requests authentication.

        A proxy set with this function will be used for all requests issued by
        **QNetworkAccessManager** . In some cases, it might be necessary to
        select different proxies depending on the type of request being sent or
        the destination host. If that's the case, you should consider using
        **setProxyFactory** ().

        **See also** **proxy** () and **proxyAuthenticationRequired** ().
        """
        ...

    def proxy(self) -> "QNetworkProxy":
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#proxy

        **QNetworkProxy QNetworkAccessManager::proxy() const**

        Returns the **QNetworkProxy**  that the requests sent using this
        **QNetworkAccessManager**  object will use. The default value for the
        proxy is **QNetworkProxy::DefaultProxy** .

        **See also** **setProxy** (), **setProxyFactory** (), and
        **proxyAuthenticationRequired** ().
        """
        ...

    @property
    def authenticationRequired(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#authenticationRequired

        **[signal] void
        QNetworkAccessManager::authenticationRequired(QNetworkReply * reply ,
        QAuthenticator * authenticator )**

        This signal is emitted whenever a final server requests authentication
        before it delivers the requested contents. The slot connected to this
        signal should fill the credentials for the contents (which can be
        determined by inspecting the **reply** object) in the **authenticator**
        object.

        **QNetworkAccessManager**  will cache the credentials internally and
        will send the same values if the server requires authentication again,
        without emitting the authenticationRequired() signal. If it rejects the
        credentials, this signal will be emitted again.

        **Note:** To have the request not send credentials you must not call
        setUser() or setPassword() on the **authenticator** object. This will
        result in the **finished** () signal being emitted with a
        **QNetworkReply**  with error **AuthenticationRequiredError** .

        **Note:** It is not possible to use a QueuedConnection to connect to
        this signal, as the connection will fail if the authenticator has not
        been filled in with new information when the signal returns.

        **See also** **proxyAuthenticationRequired** (),
        **QAuthenticator::setUser** (), and **QAuthenticator::setPassword** ().
        """
        ...

    @property
    def encrypted(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#encrypted

        **[signal, since 5.1] void
        QNetworkAccessManager::encrypted(QNetworkReply * reply )**

        This signal is emitted when an SSL/TLS session has successfully
        completed the initial handshake. At this point, no user data has been
        transmitted. The signal can be used to perform additional checks on the
        certificate chain, for example to notify users when the certificate for
        a website has changed. The **reply** parameter specifies which network
        reply is responsible. If the reply does not match the expected criteria
        then it should be aborted by calling **QNetworkReply::abort** () by a
        slot connected to this signal. The SSL configuration in use can be
        inspected using the **QNetworkReply::sslConfiguration** () method.

        Internally, **QNetworkAccessManager**  may open multiple connections to
        a server, in order to allow it process requests in parallel. These
        connections may be reused, which means that the encrypted() signal would
        not be emitted. This means that you are only guaranteed to receive this
        signal for the first connection to a site in the lifespan of the
        **QNetworkAccessManager** .

        This function was introduced in Qt 5.1.

        **See also** **QSslSocket::encrypted** () and
        **QNetworkReply::encrypted** ().
        """
        ...

    @property
    def finished(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#finished

        **[signal] void QNetworkAccessManager::finished(QNetworkReply * reply
        )**

        This signal is emitted whenever a pending network reply is finished. The
        **reply** parameter will contain a pointer to the reply that has just
        finished. This signal is emitted in tandem with the
        **QNetworkReply::finished** () signal.

        See **QNetworkReply::finished** () for information on the status that
        the object will be in.

        **Note:** Do not delete the **reply** object in the slot connected to
        this signal. Use **deleteLater** ().

        **See also** **QNetworkReply::finished** () and **QNetworkReply::error**
        ().
        """
        ...

    @property
    def preSharedKeyAuthenticationRequired(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#preSharedKeyAuthentica
        tionRequired

        **[signal, since 5.5] void
        QNetworkAccessManager::preSharedKeyAuthenticationRequired(QNetworkReply
        * reply , QSslPreSharedKeyAuthenticator * authenticator )**

        This signal is emitted if the SSL/TLS handshake negotiates a PSK
        ciphersuite, and therefore a PSK authentication is then required. The
        **reply** object is the **QNetworkReply**  that is negotiating such
        ciphersuites.

        When using PSK, the client must send to the server a valid identity and
        a valid pre shared key, in order for the SSL handshake to continue.
        Applications can provide this information in a slot connected to this
        signal, by filling in the passed **authenticator** object according to
        their needs.

        **Note:** Ignoring this signal, or failing to provide the required
        credentials, will cause the handshake to fail, and therefore the
        connection to be aborted.

        **Note:** The **authenticator** object is owned by the reply and must
        not be deleted by the application.

        This function was introduced in Qt 5.5.

        **See also** **QSslPreSharedKeyAuthenticator** .
        """
        ...

    @property
    def proxyAuthenticationRequired(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#proxyAuthenticationReq
        uired

        **[signal] void QNetworkAccessManager::proxyAuthenticationRequired(const
        QNetworkProxy & proxy , QAuthenticator * authenticator )**

        This signal is emitted whenever a proxy requests authentication and
        **QNetworkAccessManager**  cannot find a valid, cached credential. The
        slot connected to this signal should fill in the credentials for the
        proxy **proxy** in the **authenticator** object.

        **QNetworkAccessManager**  will cache the credentials internally. The
        next time the proxy requests authentication, **QNetworkAccessManager**
        will automatically send the same credential without emitting the
        proxyAuthenticationRequired signal again.

        If the proxy rejects the credentials, **QNetworkAccessManager**  will
        emit the signal again.

        **See also** **proxy** (), **setProxy** (), and
        **authenticationRequired** ().
        """
        ...

    @property
    def sslErrors(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qnetworkaccessmanager.html#sslErrors

        **[signal] void QNetworkAccessManager::sslErrors(QNetworkReply * reply ,
        const QList<QSslError> & errors )**

        This signal is emitted if the SSL/TLS session encountered errors during
        the set up, including certificate verification errors. The **errors**
        parameter contains the list of errors and **reply** is the
        **QNetworkReply**  that is encountering these errors.

        To indicate that the errors are not fatal and that the connection should
        proceed, the **QNetworkReply::ignoreSslErrors** () function should be
        called from the slot connected to this signal. If it is not called, the
        SSL session will be torn down before any data is exchanged (including
        the URL).

        This signal can be used to display an error message to the user
        indicating that security may be compromised and display the SSL settings
        (see sslConfiguration() to obtain it). If the user decides to proceed
        after analyzing the remote certificate, the slot should call
        ignoreSslErrors().

        **See also** **QSslSocket::sslErrors** (), **QNetworkReply::sslErrors**
        (), **QNetworkReply::sslConfiguration** (), and
        **QNetworkReply::ignoreSslErrors** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QGraphicsPixmapItem(QGraphicsItem):
    """
    https://doc.qt.io/qt-6/qgraphicspixmapitem.html

    **Detailed Description**

    To set the item's pixmap, pass a **QPixmap**  to QGraphicsPixmapItem's
    constructor, or call the **setPixmap** () function. The **pixmap** ()
    function returns the current pixmap.

    QGraphicsPixmapItem uses pixmap's optional alpha mask to provide a
    reasonable implementation of **boundingRect** (), **shape** (), and
    **contains** ().

    ![](images/graphicsview-pixmapitem.png)

    The pixmap is drawn at the item's (0, 0) coordinate, as returned by
    **offset** (). You can change the drawing offset by calling **setOffset**
    ().

    You can set the pixmap's transformation mode by calling
    **setTransformationMode** (). By default, **Qt::FastTransformation**  is
    used, which provides fast, non-smooth scaling. **Qt::SmoothTransformation**
    enables **QPainter::SmoothPixmapTransform**  on the painter, and the quality
    depends on the platform and viewport. The result is usually not as good as
    calling QPixmap::scale() directly. Call **transformationMode** () to get the
    current transformation mode for the item.

    **See also** **QGraphicsPathItem** , **QGraphicsRectItem** ,
    **QGraphicsEllipseItem** , **QGraphicsTextItem** , **QGraphicsPolygonItem**
    , **QGraphicsLineItem** , and **Graphics View Framework** .
    """

    class ShapeMode(enum.Enum):
        MaskShape: QGraphicsPixmapItem = ...
        BoundingRectShape: QGraphicsPixmapItem = ...
        HeuristicMaskShape: QGraphicsPixmapItem = ...

    @typing.overload
    def __init__(self, parent: typing.Optional[QGraphicsItem] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicspixmapitem.html#QGraphicsPixmapItem

        **QGraphicsPixmapItem::QGraphicsPixmapItem(QGraphicsItem * parent =
        nullptr)**

        Constructs a QGraphicsPixmapItem. **parent** is passed to
        **QGraphicsItem** 's constructor.

        **See also** **QGraphicsScene::addItem** ().
        """
        ...

    @typing.overload
    def __init__(
        self, pixmap: QtGui.QPixmap, parent: typing.Optional[QGraphicsItem] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicspixmapitem.html#QGraphicsPixmapItem-1

        **QGraphicsPixmapItem::QGraphicsPixmapItem(const QPixmap & pixmap ,
        QGraphicsItem * parent = nullptr)**

        Constructs a QGraphicsPixmapItem, using **pixmap** as the default
        pixmap. **parent** is passed to **QGraphicsItem** 's constructor.

        **See also** **QGraphicsScene::addItem** ().
        """
        ...

    def setShapeMode(self, mode: "QGraphicsPixmapItem.ShapeMode") -> None:
        """
        https://doc.qt.io/qt-6/qgraphicspixmapitem.html#setShapeMode

        **void QGraphicsPixmapItem::setShapeMode(QGraphicsPixmapItem::ShapeMode
        mode )**

        Sets the item's shape mode to **mode**. The shape mode describes how
        **QGraphicsPixmapItem**  calculates its shape. The default mode is
        **MaskShape** .

        **See also** **shapeMode** () and **ShapeMode** .
        """
        ...

    def shapeMode(self) -> "QGraphicsPixmapItem.ShapeMode":
        """
        https://doc.qt.io/qt-6/qgraphicspixmapitem.html#shapeMode

        **QGraphicsPixmapItem::ShapeMode QGraphicsPixmapItem::shapeMode()
        const**

        Returns the item's shape mode. The shape mode describes how
        **QGraphicsPixmapItem**  calculates its shape. The default mode is
        **MaskShape** .

        **See also** **setShapeMode** () and **ShapeMode** .
        """
        ...

    def type(self) -> int:
        """
        https://doc.qt.io/qt-6/qgraphicspixmapitem.html#type

        **[override virtual] int QGraphicsPixmapItem::type() const**

        Reimplements: **QGraphicsItem::type() const** .
        """
        ...

    def opaqueArea(self) -> QtGui.QPainterPath:
        """
        https://doc.qt.io/qt-6/qgraphicspixmapitem.html#opaqueArea

        **[override virtual] QPainterPath QGraphicsPixmapItem::opaqueArea()
        const**

        Reimplements: **QGraphicsItem::opaqueArea() const** .
        """
        ...

    def isObscuredBy(self, item: QGraphicsItem) -> bool:
        """
        https://doc.qt.io/qt-6/qgraphicspixmapitem.html#isObscuredBy

        **[override virtual] bool QGraphicsPixmapItem::isObscuredBy(const
        QGraphicsItem * item ) const**

        Reimplements: **QGraphicsItem::isObscuredBy(const QGraphicsItem *item)
        const** .
        """
        ...

    def paint(
        self,
        painter: QtGui.QPainter,
        option: "QStyleOptionGraphicsItem",
        widget: QWidget,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicspixmapitem.html#paint

        **[override virtual] void QGraphicsPixmapItem::paint(QPainter * painter
        , const QStyleOptionGraphicsItem * option , QWidget * widget )**

        Reimplements: **QGraphicsItem::paint** (QPainter *painter, const
        QStyleOptionGraphicsItem *option, QWidget *widget).
        """
        ...

    def contains(self, point: QtCore.QPointF) -> bool:
        """
        https://doc.qt.io/qt-6/qgraphicspixmapitem.html#contains

        **[override virtual] bool QGraphicsPixmapItem::contains(const QPointF &
        point ) const**

        Reimplements: **QGraphicsItem::contains(const QPointF &point) const** .
        """
        ...

    def shape(self) -> QtGui.QPainterPath:
        """
        https://doc.qt.io/qt-6/qgraphicspixmapitem.html#shape

        **[override virtual] QPainterPath QGraphicsPixmapItem::shape() const**

        Reimplements: **QGraphicsItem::shape() const** .
        """
        ...

    def boundingRect(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qgraphicspixmapitem.html#boundingRect

        **[override virtual] QRectF QGraphicsPixmapItem::boundingRect() const**

        Reimplements: **QGraphicsItem::boundingRect() const** .
        """
        ...

    @typing.overload
    def setOffset(self, offset: QtCore.QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicspixmapitem.html#setOffset

        **void QGraphicsPixmapItem::setOffset(const QPointF & offset )**

        Sets the pixmap item's offset to **offset**. **QGraphicsPixmapItem**
        will draw its pixmap using **offset** for its top-left corner.

        **See also** **offset** ().
        """
        ...

    @typing.overload
    def setOffset(self, ax: float, ay: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicspixmapitem.html#setOffset-1

        **void QGraphicsPixmapItem::setOffset(qreal x , qreal y )**

        This convenience function is equivalent to calling setOffset(**QPointF**
        ( **x** , **y** )).
        """
        ...

    def offset(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qgraphicspixmapitem.html#offset

        **QPointF QGraphicsPixmapItem::offset() const**

        Returns the pixmap item's **offset** , which defines the point of the
        top-left corner of the pixmap, in local coordinates.

        **See also** **setOffset** ().
        """
        ...

    def setTransformationMode(self, mode: QtCore.Qt.TransformationMode) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicspixmapitem.html#setTransformationMode

        **void QGraphicsPixmapItem::setTransformationMode(Qt::TransformationMode
        mode )**

        Sets the pixmap item's transformation mode to **mode** , and toggles an
        update of the item. The default mode is **Qt::FastTransformation** ,
        which provides quick transformation with no smoothing.

        **Qt::SmoothTransformation**  enables
        **QPainter::SmoothPixmapTransform**  on the painter, and the quality
        depends on the platform and viewport. The result is usually not as good
        as calling QPixmap::scale() directly.

        **See also** **transformationMode** ().
        """
        ...

    def transformationMode(self) -> QtCore.Qt.TransformationMode:
        """
        https://doc.qt.io/qt-6/qgraphicspixmapitem.html#transformationMode

        **Qt::TransformationMode QGraphicsPixmapItem::transformationMode()
        const**

        Returns the transformation mode of the pixmap. The default mode is
        **Qt::FastTransformation** , which provides quick transformation with no
        smoothing.

        **See also** **setTransformationMode** ().
        """
        ...

    def setPixmap(self, pixmap: QtGui.QPixmap) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicspixmapitem.html#setPixmap

        **void QGraphicsPixmapItem::setPixmap(const QPixmap & pixmap )**

        Sets the item's pixmap to **pixmap**.

        **See also** **pixmap** ().
        """
        ...

    def pixmap(self) -> QtGui.QPixmap:
        """
        https://doc.qt.io/qt-6/qgraphicspixmapitem.html#pixmap

        **QPixmap QGraphicsPixmapItem::pixmap() const**

        Returns the item's pixmap, or an invalid **QPixmap**  if no pixmap has
        been set.

        **See also** **setPixmap** ().
        """
        ...
